/*! elementor-pro - v3.5.2 - 28-11-2021 */
.elementor-bg-transform .elementor-bg {
  will-change: transform; }

.elementor-bg-transform-zoom-in:hover .elementor-bg {
  -webkit-transform: scale(1.2);
      -ms-transform: scale(1.2);
          transform: scale(1.2); }

.elementor-bg-transform-zoom-out .elementor-bg {
  -webkit-transform: scale(1.2);
      -ms-transform: scale(1.2);
          transform: scale(1.2); }

.elementor-bg-transform-zoom-out:hover .elementor-bg {
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1); }

.elementor-bg-transform-move-left .elementor-bg {
  -webkit-transform: scale(1.2) translateX(8%);
      -ms-transform: scale(1.2) translateX(8%);
          transform: scale(1.2) translateX(8%); }

.elementor-bg-transform-move-left:hover .elementor-bg {
  -webkit-transform: scale(1.2) translateX(-8%);
      -ms-transform: scale(1.2) translateX(-8%);
          transform: scale(1.2) translateX(-8%); }

.elementor-bg-transform-move-right .elementor-bg {
  -webkit-transform: scale(1.2) translateX(-8%);
      -ms-transform: scale(1.2) translateX(-8%);
          transform: scale(1.2) translateX(-8%); }

.elementor-bg-transform-move-right:hover .elementor-bg {
  -webkit-transform: scale(1.2) translateX(8%);
      -ms-transform: scale(1.2) translateX(8%);
          transform: scale(1.2) translateX(8%); }

.elementor-bg-transform-move-up .elementor-bg {
  -webkit-transform: scale(1.2) translateY(8%);
      -ms-transform: scale(1.2) translateY(8%);
          transform: scale(1.2) translateY(8%); }

.elementor-bg-transform-move-up:hover .elementor-bg {
  -webkit-transform: scale(1.2) translateY(-8%);
      -ms-transform: scale(1.2) translateY(-8%);
          transform: scale(1.2) translateY(-8%); }

.elementor-bg-transform-move-down .elementor-bg {
  -webkit-transform: scale(1.2) translateY(-8%);
      -ms-transform: scale(1.2) translateY(-8%);
          transform: scale(1.2) translateY(-8%); }

.elementor-bg-transform-move-down:hover .elementor-bg {
  -webkit-transform: scale(1.2) translateY(8%);
      -ms-transform: scale(1.2) translateY(8%);
          transform: scale(1.2) translateY(8%); }

/*---------------------------------------------------------------------------*/
.elementor-animated-content {
  --translate: 0, 0; }
  .elementor-animated-content:hover .elementor-animated-item--grow {
    -webkit-transform: scale(1.1);
        -ms-transform: scale(1.1);
            transform: scale(1.1); }
  .elementor-animated-content:hover .elementor-animated-item--shrink {
    -webkit-transform: scale(0.85);
        -ms-transform: scale(0.85);
            transform: scale(0.85); }
  .elementor-animated-content:hover .elementor-animated-item--shrink-contained {
    -webkit-transform: scale(1);
        -ms-transform: scale(1);
            transform: scale(1); }
  .elementor-animated-content:hover .elementor-animated-item--enter-zoom-out, .elementor-animated-content:hover .elementor-animated-item--enter-zoom-in, .elementor-animated-content:hover .elementor-animated-item--fade-in {
    -webkit-transform: scale(1);
        -ms-transform: scale(1);
            transform: scale(1);
    opacity: 1; }
  .elementor-animated-content:hover .elementor-animated-item--exit-zoom-out, .elementor-animated-content:hover .elementor-animated-item--exit-zoom-in, .elementor-animated-content:hover .elementor-animated-item--fade-out {
    opacity: 0; }
  .elementor-animated-content:hover .elementor-animated-item--exit-zoom-out {
    -webkit-transform: scale(0.2);
        -ms-transform: scale(0.2);
            transform: scale(0.2); }
  .elementor-animated-content:hover .elementor-animated-item--exit-zoom-in {
    -webkit-transform: scale(2);
        -ms-transform: scale(2);
            transform: scale(2); }
  .elementor-animated-content:hover .elementor-animated-item--enter-from-right, .elementor-animated-content:hover .elementor-animated-item--enter-from-left, .elementor-animated-content:hover .elementor-animated-item--enter-from-top, .elementor-animated-content:hover .elementor-animated-item--enter-from-bottom {
    opacity: 1;
    -webkit-transform: translateY(0) translateX(0);
        -ms-transform: translateY(0) translateX(0);
            transform: translateY(0) translateX(0); }
  .elementor-animated-content:hover .elementor-animated-item--exit-to-right {
    -webkit-transform: translateX(1000px);
        -ms-transform: translateX(1000px);
            transform: translateX(1000px); }
  .elementor-animated-content:hover .elementor-animated-item--exit-to-left {
    -webkit-transform: translateX(-1000px);
        -ms-transform: translateX(-1000px);
            transform: translateX(-1000px); }
  .elementor-animated-content:hover .elementor-animated-item--exit-to-top {
    -webkit-transform: translateY(-600px);
        -ms-transform: translateY(-600px);
            transform: translateY(-600px); }
  .elementor-animated-content:hover .elementor-animated-item--exit-to-bottom {
    -webkit-transform: translateY(600px);
        -ms-transform: translateY(600px);
            transform: translateY(600px); }
  .elementor-animated-content:hover .elementor-animated-item--exit-to-right, .elementor-animated-content:hover .elementor-animated-item--exit-to-left, .elementor-animated-content:hover .elementor-animated-item--exit-to-top, .elementor-animated-content:hover .elementor-animated-item--exit-to-bottom {
    opacity: 0; }
  .elementor-animated-content:hover .elementor-animated-item--move-right {
    -webkit-transform: translateX(30px);
        -ms-transform: translateX(30px);
            transform: translateX(30px); }
  .elementor-animated-content:hover .elementor-animated-item--move-left {
    -webkit-transform: translateX(-30px);
        -ms-transform: translateX(-30px);
            transform: translateX(-30px); }
  .elementor-animated-content:hover .elementor-animated-item--move-up {
    -webkit-transform: translateY(-30px);
        -ms-transform: translateY(-30px);
            transform: translateY(-30px); }
  .elementor-animated-content:hover .elementor-animated-item--move-down {
    -webkit-transform: translateY(30px);
        -ms-transform: translateY(30px);
            transform: translateY(30px); }
  .elementor-animated-content:hover .elementor-animated-item--move-contained-right {
    --translate: 8%, 0; }
  .elementor-animated-content:hover .elementor-animated-item--move-contained-left {
    --translate: -8%, 0; }
  .elementor-animated-content:hover .elementor-animated-item--move-contained-top {
    --translate: 0, -8%; }
  .elementor-animated-content:hover .elementor-animated-item--move-contained-bottom {
    --translate: 0, 8%; }
  .elementor-animated-content *[class^="elementor-animated-item"] {
    will-change: transform, opacity; }
  .elementor-animated-content .elementor-animated-item--shrink-contained {
    -webkit-transform: scale(1.17);
        -ms-transform: scale(1.17);
            transform: scale(1.17); }
  .elementor-animated-content .elementor-animated-item--enter-zoom-in {
    -webkit-transform: scale(0.2);
        -ms-transform: scale(0.2);
            transform: scale(0.2); }
  .elementor-animated-content .elementor-animated-item--enter-zoom-out {
    -webkit-transform: scale(2);
        -ms-transform: scale(2);
            transform: scale(2); }
  .elementor-animated-content .elementor-animated-item--enter-zoom-out, .elementor-animated-content .elementor-animated-item--enter-zoom-in, .elementor-animated-content .elementor-animated-item--fade-in {
    opacity: 0; }
  .elementor-animated-content .elementor-animated-item--exit-zoom-out, .elementor-animated-content .elementor-animated-item--exit-zoom-in, .elementor-animated-content .elementor-animated-item--fade-out {
    opacity: 1;
    -webkit-transform: scale(1);
        -ms-transform: scale(1);
            transform: scale(1); }
  .elementor-animated-content .elementor-animated-item--enter-from-right {
    -webkit-transform: translateX(1000px);
        -ms-transform: translateX(1000px);
            transform: translateX(1000px); }
  .elementor-animated-content .elementor-animated-item--enter-from-left {
    -webkit-transform: translateX(-1000px);
        -ms-transform: translateX(-1000px);
            transform: translateX(-1000px); }
  .elementor-animated-content .elementor-animated-item--enter-from-top {
    -webkit-transform: translateY(-600px);
        -ms-transform: translateY(-600px);
            transform: translateY(-600px); }
  .elementor-animated-content .elementor-animated-item--enter-from-bottom {
    -webkit-transform: translateY(500px);
        -ms-transform: translateY(500px);
            transform: translateY(500px); }
  .elementor-animated-content .elementor-animated-item--enter-from-right, .elementor-animated-content .elementor-animated-item--enter-from-left, .elementor-animated-content .elementor-animated-item--enter-from-top, .elementor-animated-content .elementor-animated-item--enter-from-bottom {
    opacity: 0; }
  .elementor-animated-content .elementor-animated-item--exit-to-right, .elementor-animated-content .elementor-animated-item--exit-to-left, .elementor-animated-content .elementor-animated-item--exit-to-top, .elementor-animated-content .elementor-animated-item--exit-to-bottom {
    opacity: 1;
    -webkit-transform: translateY(0) translateX(0);
        -ms-transform: translateY(0) translateX(0);
            transform: translateY(0) translateX(0); }
  .elementor-animated-content .elementor-animated-item--move-contained-right, .elementor-animated-content .elementor-animated-item--move-contained-left, .elementor-animated-content .elementor-animated-item--move-contained-top, .elementor-animated-content .elementor-animated-item--move-contained-bottom {
    -webkit-transform: scale(1.2) translate(var(--translate));
        -ms-transform: scale(1.2) translate(var(--translate));
            transform: scale(1.2) translate(var(--translate)); }

.elementor-editor-active .elementor.elementor-edit-mode .elementor-widget.elementor-global-widget:hover {
  outline: 1px solid #fec449; }

.elementor-editor-active .elementor.elementor-edit-mode .elementor-global-widget .elementor-editor-widget-settings {
  background-image: -webkit-gradient(linear, left bottom, left top, from(#feb416), to(#fec449));
  background-image: -webkit-linear-gradient(bottom, #feb416, #fec449);
  background-image: -o-linear-gradient(bottom, #feb416, #fec449);
  background-image: linear-gradient(to top, #feb416, #fec449); }
  .elementor-editor-active .elementor.elementor-edit-mode .elementor-global-widget .elementor-editor-widget-settings .elementor-editor-element-setting:hover {
    background-color: #feb416; }
  .elementor-editor-active .elementor.elementor-edit-mode .elementor-global-widget .elementor-editor-widget-settings .elementor-editor-element-setting.elementor-editor-element-save {
    display: none; }

body.woocommerce #content div.product .elementor-widget-woocommerce-product-images div.images,
body.woocommerce div.product .elementor-widget-woocommerce-product-images div.images, body.woocommerce-page #content div.product .elementor-widget-woocommerce-product-images div.images,
body.woocommerce-page div.product .elementor-widget-woocommerce-product-images div.images {
  float: none;
  width: 100%;
  padding: 0; }

body.rtl.woocommerce #content div.product .elementor-widget-woocommerce-product-images div.images,
body.rtl.woocommerce div.product .elementor-widget-woocommerce-product-images div.images, body.rtl.woocommerce-page #content div.product .elementor-widget-woocommerce-product-images div.images,
body.rtl.woocommerce-page div.product .elementor-widget-woocommerce-product-images div.images {
  float: none;
  padding: 0; }

.woocommerce div.product.elementor form.cart:not(.grouped_form):not(.variations_form),
.woocommerce div.product.elementor form.cart.variations_form .woocommerce-variation-add-to-cart {
  margin: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }

.woocommerce div.product.elementor .quantity .qty {
  vertical-align: top;
  margin-right: 0; }

.woocommerce div.product.elementor .quantity + .button {
  margin-left: 10px; }

.woocommerce div.product.elementor .woocommerce-variation-add-to-cart .quantity input {
  height: 100%; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart:not(.grouped_form):not(.variations_form),
.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart.variations_form .woocommerce-variation-add-to-cart {
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart:not(.grouped_form):not(.variations_form),
.woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart.variations_form .woocommerce-variation-add-to-cart {
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart:not(.grouped_form):not(.variations_form),
.woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart.variations_form .woocommerce-variation-add-to-cart {
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart:not(.grouped_form):not(.variations_form) div.quantity,
.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart:not(.grouped_form):not(.variations_form) div.quantity,
.woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart:not(.grouped_form):not(.variations_form) div.quantity,
.woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
  margin-right: initial; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart:not(.grouped_form):not(.variations_form) button,
.woocommerce div.product.elementor .elementor-add-to-cart--align-left form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart:not(.grouped_form):not(.variations_form) button,
.woocommerce div.product.elementor .elementor-add-to-cart--align-right form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart:not(.grouped_form):not(.variations_form) button,
.woocommerce div.product.elementor .elementor-add-to-cart--align-center form.cart.variations_form .woocommerce-variation-add-to-cart button {
  -ms-flex-preferred-size: auto;
      flex-basis: auto; }

.woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart:not(.grouped_form):not(.variations_form),
.woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart {
  -ms-flex-wrap: nowrap;
      flex-wrap: nowrap; }
  .woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
    margin-right: auto; }
  .woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart button {
    -ms-flex-preferred-size: 100%;
        flex-basis: 100%; }

@media (max-width: 1024px) {
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start; }
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: end;
        -ms-flex-pack: end;
            justify-content: flex-end; }
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
    margin-right: initial; }
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-left form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-right form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-center form.cart.variations_form .woocommerce-variation-add-to-cart button {
    -ms-flex-preferred-size: auto;
        flex-basis: auto; }
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap; }
    .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart:not(.grouped_form):not(.variations_form) div.quantity,
    .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
      margin-right: auto; }
    .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart:not(.grouped_form):not(.variations_form) button,
    .woocommerce div.product.elementor .elementor-add-to-cart-tablet--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart button {
      -ms-flex-preferred-size: 100%;
          flex-basis: 100%; } }

@media (max-width: 767px) {
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: start;
        -ms-flex-pack: start;
            justify-content: flex-start; }
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: end;
        -ms-flex-pack: end;
            justify-content: flex-end; }
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart.variations_form .woocommerce-variation-add-to-cart {
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity, .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart:not(.grouped_form):not(.variations_form) div.quantity,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
    margin-right: initial; }
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-left form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-right form.cart.variations_form .woocommerce-variation-add-to-cart button, .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart:not(.grouped_form):not(.variations_form) button,
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-center form.cart.variations_form .woocommerce-variation-add-to-cart button {
    -ms-flex-preferred-size: auto;
        flex-basis: auto; }
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart:not(.grouped_form):not(.variations_form),
  .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart {
    -ms-flex-wrap: nowrap;
        flex-wrap: nowrap; }
    .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart:not(.grouped_form):not(.variations_form) div.quantity,
    .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart div.quantity {
      margin-right: auto; }
    .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart:not(.grouped_form):not(.variations_form) button,
    .woocommerce div.product.elementor .elementor-add-to-cart-mobile--align-justify form.cart.variations_form .woocommerce-variation-add-to-cart button {
      -ms-flex-preferred-size: 100%;
          flex-basis: 100%; } }

.woocommerce div.product.elementor .elementor-widget-wc-add-to-cart.elementor-button-info button.button.alt.elementor-button {
  background-color: #5bc0de; }

.woocommerce div.product.elementor .elementor-widget-wc-add-to-cart.elementor-button-success button.button.alt.elementor-button {
  background-color: #5cb85c; }

.woocommerce div.product.elementor .elementor-widget-wc-add-to-cart.elementor-button-warning button.button.alt.elementor-button {
  background-color: #f0ad4e; }

.woocommerce div.product.elementor .elementor-widget-wc-add-to-cart.elementor-button-danger button.button.alt.elementor-button {
  background-color: #d9534f; }

.elementor-widget-wc-add-to-cart .quantity {
  display: inline-block; }

.elementor-widget-wc-add-to-cart.elementor-align-center form.cart {
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }

.elementor-widget-wc-add-to-cart.elementor-align-right form.cart {
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.elementor-widget-wc-add-to-cart.elementor-align-left form.cart {
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.woocommerce div.product.elementor {
  /*  Reset WC tabs style  */
  /*  End Reset WC tabs style  */ }
  .woocommerce div.product.elementor ul.tabs:before {
    position: static;
    content: none;
    width: auto;
    bottom: auto;
    left: auto;
    border-bottom: 0;
    z-index: auto; }
  .woocommerce div.product.elementor ul.tabs {
    margin: 0; }
    .woocommerce div.product.elementor ul.tabs li {
      padding: 0; }
      .woocommerce div.product.elementor ul.tabs li a {
        padding: .8em 1.2em;
        line-height: 1; }
    .woocommerce div.product.elementor ul.tabs li:after,
    .woocommerce div.product.elementor ul.tabs li:before {
      border: 0;
      position: static;
      bottom: auto;
      width: auto;
      height: auto;
      content: none;
      -webkit-box-sizing: border-box;
              box-sizing: border-box; }
  .woocommerce div.product.elementor .woocommerce-tabs .panel {
    margin: 0;
    padding: 20px;
    border-radius: 0;
    border-width: 0;
    border-top: 1px solid #d3ced2;
    -webkit-box-shadow: none;
            box-shadow: none;
    margin-top: -1px; }

.woocommerce div.product.elementor .elementor-product-price-block-yes .price del,
.woocommerce div.product.elementor .elementor-product-price-block-yes .price ins {
  display: block; }

.elementor-widget-woocommerce-product-meta .detail-container {
  position: relative; }
  .elementor-widget-woocommerce-product-meta .detail-container:after {
    position: absolute;
    bottom: 0;
    left: 0;
    width: 100%; }

.elementor-widget-woocommerce-product-meta .detail-label {
  font-weight: bold; }

.elementor-woo-meta--view-inline .product_meta {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -ms-flex-wrap: wrap;
      flex-wrap: wrap; }
  .elementor-woo-meta--view-inline .product_meta .detail-container:after {
    width: auto;
    left: auto;
    right: auto;
    position: absolute;
    height: 100%;
    top: 50%;
    -webkit-transform: translateY(-50%);
        -ms-transform: translateY(-50%);
            transform: translateY(-50%);
    border-top: 0;
    border-bottom: 0;
    border-right: 0;
    border-left-width: 1px;
    border-style: solid;
    right: -8px; }

.elementor-woo-meta--view-table .product_meta {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column; }
  .elementor-woo-meta--view-table .product_meta .detail-container {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
  .elementor-woo-meta--view-table .product_meta .detail-label {
    min-width: 108px; }

.elementor-woo-meta--view-stacked .product_meta .detail-container {
  display: block; }

.woocommerce div.product.elementor .woocommerce-product-rating {
  margin-bottom: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }

.woocommerce div.product.elementor .star-rating {
  margin-top: 0; }

.elementor-product-rating--align-left .woocommerce-product-rating {
  -webkit-box-pack: start;
      -ms-flex-pack: start;
          justify-content: flex-start; }

.elementor-product-rating--align-right .woocommerce-product-rating {
  -webkit-box-pack: end;
      -ms-flex-pack: end;
          justify-content: flex-end; }

.elementor-product-rating--align-center .woocommerce-product-rating {
  -webkit-box-pack: center;
      -ms-flex-pack: center;
          justify-content: center; }

.elementor-product-rating--align-justify .woocommerce-product-rating .woocommerce-review-link {
  margin-left: auto; }

.elementor-products-grid ul.products.elementor-grid {
  display: grid;
  margin: 0;
  grid-column-gap: 20px;
  grid-row-gap: 40px; }
  .elementor-products-grid ul.products.elementor-grid:before, .elementor-products-grid ul.products.elementor-grid:after {
    content: none;
    display: none; }
  .elementor-products-grid ul.products.elementor-grid li.product {
    width: auto;
    padding: 0;
    margin: 0;
    float: none; }
    .elementor-products-grid ul.products.elementor-grid li.product .onsale {
      padding: 0;
      display: none; }
    .elementor-products-grid ul.products.elementor-grid li.product a.woocommerce-loop-product__link {
      display: block;
      position: relative; }

.elementor-products-grid:not(.show-heading-yes) .products > h2 {
  display: none; }

.elementor-products-grid nav.woocommerce-pagination {
  margin-top: 40px; }

.elementor-products-grid:not(.elementor-show-pagination-border-yes) nav.woocommerce-pagination ul {
  border: none 0; }

.elementor-products-grid:not(.elementor-show-pagination-border-yes) nav.woocommerce-pagination ul li {
  border-right: none 0;
  border-left: none 0; }

.elementor-product-loop-item--align-left ul.products li.product .star-rating {
  margin-right: auto; }

.elementor-product-loop-item--align-right ul.products li.product .star-rating {
  margin-left: auto; }

.elementor-product-loop-item--align-center ul.products li.product .star-rating {
  margin-right: auto;
  margin-left: auto; }

.woocommerce .elementor-element.elementor-products-grid ul.products li.product {
  width: auto; }

.woocommerce div.product .elementor-element.elementor-products-grid .related.products ul.products li.product,
.woocommerce div.product .elementor-element.elementor-products-grid .upsells.products ul.products li.product {
  width: auto; }

@media (min-width: 1025px) {
  .elementor-widget-wc-archive-products .woocommerce.columns-2 ul.products {
    grid-template-columns: repeat(2, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-3 ul.products {
    grid-template-columns: repeat(3, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-4 ul.products {
    grid-template-columns: repeat(4, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-5 ul.products {
    grid-template-columns: repeat(5, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-6 ul.products {
    grid-template-columns: repeat(6, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-7 ul.products {
    grid-template-columns: repeat(7, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-8 ul.products {
    grid-template-columns: repeat(8, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-9 ul.products {
    grid-template-columns: repeat(9, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-10 ul.products {
    grid-template-columns: repeat(10, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-11 ul.products {
    grid-template-columns: repeat(11, 1fr); }
  .elementor-widget-wc-archive-products .woocommerce.columns-12 ul.products {
    grid-template-columns: repeat(12, 1fr); } }

@media (max-width: 1024px) {
  .elementor-widget-wc-archive-products .products {
    grid-template-columns: repeat(3, 1fr); } }

@media (max-width: 767px) {
  .elementor-widget-wc-archive-products .products {
    grid-template-columns: repeat(2, 1fr); } }

.elementor.product .woocommerce-product-gallery__trigger + .woocommerce-product-gallery__wrapper {
  overflow: hidden; }

.woocommerce .elementor-widget-woocommerce-product-images span.onsale {
  padding: 0; }

.elementor-menu-cart__wrapper {
  text-align: var(--main-alignment, left); }

.elementor-menu-cart__toggle_wrapper {
  display: inline-block;
  position: relative; }

.elementor-menu-cart__toggle {
  display: inline-block; }
  .elementor-menu-cart__toggle .elementor-button {
    background-color: var(--toggle-button-background-color, transparent);
    color: var(--toggle-button-text-color, #818a91);
    border-style: var(--toggle-button-border-type, solid);
    border-width: var(--toggle-button-border-width, 1px);
    border-color: var(--toggle-button-border-color, #818a91);
    border-radius: var(--toggle-button-border-radius, 0px);
    display: -webkit-inline-box;
    display: -ms-inline-flexbox;
    display: inline-flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    padding: var(--toggle-icon-padding, 12px 24px); }
    .elementor-menu-cart__toggle .elementor-button:hover {
      color: var(--toggle-button-hover-text-color, #818a91);
      background-color: var(--toggle-button-hover-background-color, transparent);
      border-color: var(--toggle-button-hover-border-color, #818a91); }
      .elementor-menu-cart__toggle .elementor-button:hover .elementor-button-icon {
        color: var(--toggle-button-icon-hover-color, #818a91); }
  .elementor-menu-cart__toggle .elementor-button-text {
    margin-right: 0.3em; }
  .elementor-menu-cart__toggle .elementor-button-icon {
    position: relative;
    -webkit-transition: color 0.1s;
    -o-transition: color 0.1s;
    transition: color 0.1s;
    color: var(--toggle-button-icon-color, #818a91);
    font-size: var(--toggle-icon-size, inherit); }

.elementor-menu-cart--items-indicator-bubble .elementor-menu-cart__toggle .elementor-button-icon[data-counter]:before {
  content: attr(data-counter);
  display: block;
  position: absolute;
  min-width: 1.6em;
  height: 1.6em;
  line-height: 1.5em;
  top: -0.7em;
  right: -0.7em;
  border-radius: 100%;
  color: var(--items-indicator-text-color, #fff);
  background-color: var(--items-indicator-background-color, #d9534f);
  text-align: center;
  font-size: 10px; }

.elementor-menu-cart--items-indicator-plain .elementor-menu-cart__toggle .elementor-button-icon[data-counter]:before {
  content: attr(data-counter);
  display: inline-block;
  font-weight: normal; }

.elementor-menu-cart__container {
  -webkit-transform: scale(1);
      -ms-transform: scale(1);
          transform: scale(1);
  overflow: hidden;
  position: fixed;
  z-index: 9998;
  top: 0;
  left: 0;
  width: 100vw;
  height: 100vh;
  background-color: rgba(0, 0, 0, 0.25);
  -webkit-transition: background-color 0.4s, -webkit-transform 0s;
  transition: background-color 0.4s, -webkit-transform 0s;
  -o-transition: background-color 0.4s, transform 0s;
  transition: background-color 0.4s, transform 0s;
  transition: background-color 0.4s, transform 0s, -webkit-transform 0s;
  text-align: left; }

.elementor-menu-cart__main {
  position: fixed;
  left: var(--side-cart-alignment-left, auto);
  right: var(--side-cart-alignment-right, 0);
  -webkit-transform: translateX(0);
      -ms-transform: translateX(0);
          transform: translateX(0);
  top: 0;
  bottom: 0;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: vertical;
  -webkit-box-direction: normal;
      -ms-flex-direction: column;
          flex-direction: column;
  -webkit-box-align: stretch;
      -ms-flex-align: stretch;
          align-items: stretch;
  font-size: 14px;
  min-height: 200px;
  width: 350px;
  max-width: 100%;
  -webkit-transition: 0.3s;
  -o-transition: 0.3s;
  transition: 0.3s;
  padding: var(--cart-padding, 20px 30px);
  background-color: var(--cart-background-color, #fff);
  -webkit-box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
          box-shadow: 0 0 20px rgba(0, 0, 0, 0.2);
  border-style: var(--cart-border-style, none);
  border-color: var(--cart-border-color, initial);
  border-radius: var(--cart-border-radius, 0px);
  margin-top: var(--mini-cart-spacing, 0px); }
  .elementor-menu-cart__main .widget_shopping_cart_content {
    height: 100%;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
        -ms-flex-direction: column;
            flex-direction: column; }
    .elementor-menu-cart__main .widget_shopping_cart_content .woocommerce-mini-cart__empty-message {
      color: var(--empty-message-color, inherit);
      text-align: var(--empty-message-alignment, left); }

body.elementor-default .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--shown) .elementor-menu-cart__container {
  background-color: transparent;
  -webkit-transform: scale(0);
      -ms-transform: scale(0);
          transform: scale(0);
  -webkit-transition: background-color 0.4s, -webkit-transform 0s 0.4s;
  transition: background-color 0.4s, -webkit-transform 0s 0.4s;
  -o-transition: background-color 0.4s, transform 0s 0.4s;
  transition: background-color 0.4s, transform 0s 0.4s;
  transition: background-color 0.4s, transform 0s 0.4s, -webkit-transform 0s 0.4s; }
  body.elementor-default .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--shown) .elementor-menu-cart__container .dialog-lightbox-close-button {
    display: none; }

body.elementor-default .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--shown) .elementor-menu-cart__main {
  overflow: hidden;
  opacity: 0;
  -webkit-transform: var(--side-cart-alignment-transform, translateX(100%));
      -ms-transform: var(--side-cart-alignment-transform, translateX(100%));
          transform: var(--side-cart-alignment-transform, translateX(100%)); }

.elementor-menu-cart__close-button {
  width: var(--cart-close-icon-size, 25px);
  height: var(--cart-close-icon-size, 25px);
  position: relative;
  margin: 0 0 20px;
  -ms-flex-item-align: end;
      align-self: flex-end;
  cursor: pointer;
  display: inline-block;
  font-family: eicons;
  font-size: 20px;
  line-height: 1;
  -webkit-transition: 0.3s;
  -o-transition: 0.3s;
  transition: 0.3s; }
  .elementor-menu-cart__close-button:before, .elementor-menu-cart__close-button:after {
    content: '';
    position: absolute;
    height: 3px;
    width: 100%;
    top: 50%;
    left: 0;
    margin-top: -1px;
    background: var(--cart-close-button-color, #818a91);
    border-radius: 1px;
    -webkit-transition: 0.3s;
    -o-transition: 0.3s;
    transition: 0.3s; }
  .elementor-menu-cart__close-button:hover::before, .elementor-menu-cart__close-button:hover::after {
    background: var(--cart-close-button-hover-color, #818a91); }
  .elementor-menu-cart__close-button::before {
    -webkit-transform: rotate(45deg);
        -ms-transform: rotate(45deg);
            transform: rotate(45deg); }
  .elementor-menu-cart__close-button::after {
    -webkit-transform: rotate(-45deg);
        -ms-transform: rotate(-45deg);
            transform: rotate(-45deg); }

.elementor-menu-cart__products {
  max-height: calc(100vh - 250px);
  overflow: hidden;
  overflow-y: auto;
  -webkit-overflow-scrolling: touch; }

.elementor-menu-cart__product {
  display: grid;
  grid-template-columns: 28% auto;
  grid-template-rows: var(--price-quantity-position--grid-template-rows, auto auto);
  position: relative;
  border-width: 0 0 var(--divider-width, 1px);
  border-bottom-style: var(--divider-style, solid);
  border-bottom-color: var(--divider-color, #D4D4D4); }
  .elementor-menu-cart__product .variation {
    display: grid;
    grid-template-columns: -webkit-max-content auto;
    grid-template-columns: max-content auto;
    margin: 10px 0; }
    .elementor-menu-cart__product .variation dt {
      grid-column-start: 1; }
    .elementor-menu-cart__product .variation dd {
      grid-column-start: 2;
      -webkit-margin-start: 5px;
              margin-inline-start: 5px; }
      .elementor-menu-cart__product .variation dd p {
        margin-bottom: 0; }
  .elementor-menu-cart__product-image {
    grid-row-start: 1;
    grid-row-end: 3;
    width: 100%; }
    .elementor-menu-cart__product-image img, .elementor-menu-cart__product-image a {
      display: block; }
  .elementor-menu-cart__product-name {
    grid-column-start: 2;
    grid-column-end: 3;
    margin: 0; }
    .elementor-menu-cart__product-name a {
      -webkit-transition: 0.3s;
      -o-transition: 0.3s;
      transition: 0.3s; }
  .elementor-menu-cart__product-price {
    grid-column-start: 2;
    grid-column-end: 3;
    -ms-flex-item-align: var(--price-quantity-position--align-self, end);
        align-self: var(--price-quantity-position--align-self, end);
    font-weight: 300;
    color: var(--product-price-color, #D4D4D4); }
  .elementor-menu-cart__product-name, .elementor-menu-cart__product-price {
    font-size: 14px;
    padding-left: 20px; }
  .elementor-menu-cart__product-remove {
    color: #818a91;
    width: var(--remove-item-button-size, 22px);
    height: var(--remove-item-button-size, 22px);
    border-radius: var(--remove-item-button-size, 22px);
    border: 1px solid var(--remove-item-button-color, #D4D4D4);
    text-align: center;
    overflow: hidden;
    position: absolute;
    right: 0;
    bottom: 20px;
    -webkit-transition: 0.3s;
    -o-transition: 0.3s;
    transition: 0.3s; }
    .elementor-menu-cart__product-remove:hover {
      border: 1px solid var(--remove-item-button-hover-color, #D4D4D4); }
      .elementor-menu-cart__product-remove:hover::before, .elementor-menu-cart__product-remove:hover::after {
        background: var(--remove-item-button-hover-color, #D4D4D4); }
    .elementor-menu-cart__product-remove:before, .elementor-menu-cart__product-remove:after {
      content: '';
      position: absolute;
      height: 1px;
      width: 50%;
      top: 50%;
      left: 25%;
      margin-top: -1px;
      background: var(--remove-item-button-color, #D4D4D4);
      z-index: 1;
      -webkit-transition: 0.3s;
      -o-transition: 0.3s;
      transition: 0.3s; }
    .elementor-menu-cart__product-remove::before {
      -webkit-transform: rotate(45deg);
          -ms-transform: rotate(45deg);
              transform: rotate(45deg); }
    .elementor-menu-cart__product-remove::after {
      -webkit-transform: rotate(-45deg);
          -ms-transform: rotate(-45deg);
              transform: rotate(-45deg); }
    .elementor-menu-cart__product-remove > a {
      display: block;
      z-index: 2;
      width: 100%;
      height: 100%;
      overflow: hidden;
      opacity: 0;
      position: absolute; }
      .elementor-menu-cart__product-remove > a.remove_from_cart_button {
        display: var(--remove-from-cart-button, block); }
      .elementor-menu-cart__product-remove > a.elementor_remove_from_cart_button {
        display: var(--elementor-remove-from-cart-button, none); }

.elementor-menu-cart__product:last-child {
  border: none; }

.elementor-menu-cart__product:not(:first-of-type), .elementor-menu-cart__subtotal, .elementor-menu-cart__footer-buttons {
  padding-top: var(--product-divider-gap, 20px); }

.elementor-menu-cart__product {
  padding-right: 30px; }

.elementor-menu-cart__product, .elementor-menu-cart__subtotal {
  padding-bottom: var(--product-divider-gap, 20px); }

.elementor-menu-cart__subtotal {
  font-size: 20px;
  text-align: var(--menu-cart-subtotal-text-align, center);
  font-weight: 600;
  color: var(--menu-cart-subtotal-color, inherit);
  border-style: var(--subtotal-divider-style, solid);
  border-width: var(--subtotal-divider-top-width, 1px) var(--subtotal-divider-right-width, 1px) var(--subtotal-divider-bottom-width, 1px) var(--subtotal-divider-left-width, 1px);
  border-color: var(--subtotal-divider-color, #D4D4D4); }

.elementor-menu-cart__footer-buttons {
  font-size: 20px;
  text-align: var(--cart-footer-buttons-alignment-text-align, center);
  display: var(--cart-footer-buttons-alignment-display, grid);
  grid-template-columns: var(--cart-footer-layout, 1fr 1fr);
  margin-top: var(--cart-buttons-position-margin, 0);
  grid-column-gap: var(--space-between-buttons, 10px);
  grid-row-gap: var(--space-between-buttons, 10px); }
  .elementor-menu-cart__footer-buttons .elementor-button {
    display: inline-block;
    border-radius: var(--cart-footer-buttons-border-radius, 0px);
    height: -webkit-fit-content;
    height: -moz-fit-content;
    height: fit-content; }
    .elementor-menu-cart__footer-buttons .elementor-button--view-cart {
      display: var(--view-cart-button-display, inline-block);
      color: var(--view-cart-button-text-color, #fff);
      padding: var(--view-cart-button-padding, 15px);
      background-color: var(--view-cart-button-background-color, #818a91); }
      .elementor-menu-cart__footer-buttons .elementor-button--view-cart:hover {
        color: var(--view-cart-button-hover-text-color, #fff);
        background-color: var(--view-cart-button-hover-background-color, #818a91); }
    .elementor-menu-cart__footer-buttons .elementor-button--checkout {
      display: var(--checkout-button-display, inline-block);
      color: var(--checkout-button-text-color, #fff);
      padding: var(--checkout-button-padding, 15px);
      background-color: var(--checkout-button-background-color, #818a91); }
      .elementor-menu-cart__footer-buttons .elementor-button--checkout:hover {
        color: var(--checkout-button-hover-text-color, #fff);
        background-color: var(--checkout-button-hover-background-color, #818a91); }
    @media (max-width: 767px) {
      .elementor-menu-cart__footer-buttons .elementor-button {
        padding-left: 10px;
        padding-right: 10px; } }

/* The following is all to apply settings from the controls */
.elementor-widget-woocommerce-menu-cart {
  /* Fix to prevent the cart modal flash when using the typography controls */
  /* Fix for short-lived legacy cart type */ }
  .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--show-subtotal-yes) .elementor-menu-cart__toggle .elementor-button-text {
    display: none; }
  .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--empty-indicator-hide .elementor-menu-cart__toggle .elementor-button-icon[data-counter="0"]:before {
    content: none; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--bag-light .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e3'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--bag-medium .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e4'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--bag-solid .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e5'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--basket-light .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e6'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--basket-medium .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e7'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--basket-solid .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e8'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--cart-light .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8e9'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--cart-medium .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8ea'; }
  .elementor-widget-woocommerce-menu-cart.toggle-icon--cart-solid .elementor-menu-cart__toggle .elementor-button-icon i:before {
    content: '\e8eb'; }
  .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--show-remove-button-yes) .elementor-menu-cart__product {
    padding-left: 0;
    padding-right: 0;
    grid-template-columns: 25% auto; }
  .elementor-widget-woocommerce-menu-cart:not(.elementor-menu-cart--show-remove-button-yes) .elementor-menu-cart__product-remove {
    display: none; }
  .elementor-widget-woocommerce-menu-cart.remove-item-position--top .elementor-menu-cart__product-remove {
    top: 0;
    bottom: auto; }
  .elementor-widget-woocommerce-menu-cart.remove-item-position--top .elementor-menu-cart__products .cart_item:not(:first-of-type) .elementor-menu-cart__product-remove {
    top: 20px;
    bottom: auto; }
  .elementor-widget-woocommerce-menu-cart.remove-item-position--middle .elementor-menu-cart__product-remove {
    -webkit-transform: translateY(50%);
        -ms-transform: translateY(50%);
            transform: translateY(50%);
    bottom: 50%; }
  .elementor-widget-woocommerce-menu-cart.remove-item-position--bottom .elementor-menu-cart__product-remove {
    top: auto;
    bottom: 20px; }
  .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart .elementor-menu-cart {
    /* The sticky setting in Elementor uses z-index 99 so we use 89 to keep it below sticky headers but above all other content
			and still allow 10 layers if 3rd party want to insert content between ours. */ }
    .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart .elementor-menu-cart__container {
      position: absolute;
      z-index: 89;
      width: auto;
      height: auto;
      overflow: visible;
      top: 100%;
      bottom: auto;
      background: none;
      min-width: 330px;
      left: 0;
      right: auto;
      -webkit-transform: scale(1);
          -ms-transform: scale(1);
              transform: scale(1);
      -webkit-transition: background-color 0.4s, -webkit-transform 0s;
      transition: background-color 0.4s, -webkit-transform 0s;
      -o-transition: background-color 0.4s, transform 0s;
      transition: background-color 0.4s, transform 0s;
      transition: background-color 0.4s, transform 0s, -webkit-transform 0s; }
    .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart .elementor-menu-cart__main {
      width: auto;
      height: auto;
      position: relative;
      top: auto;
      bottom: auto;
      right: auto;
      left: auto;
      overflow: visible;
      -webkit-transform: translateY(0);
          -ms-transform: translateY(0);
              transform: translateY(0);
      -webkit-transition: 0.3s;
      -o-transition: 0.3s;
      transition: 0.3s; }
    @media (max-width: 767px) {
      .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart .elementor-menu-cart__container {
        min-width: 300px; } }
  body.elementor-default .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart:not(.elementor-menu-cart--shown) .elementor-menu-cart__container {
    -webkit-transform: scale(0);
        -ms-transform: scale(0);
            transform: scale(0);
    -webkit-transition: background-color 0.4s, -webkit-transform 0s 0.4s;
    transition: background-color 0.4s, -webkit-transform 0s 0.4s;
    -o-transition: background-color 0.4s, transform 0s 0.4s;
    transition: background-color 0.4s, transform 0s 0.4s;
    transition: background-color 0.4s, transform 0s 0.4s, -webkit-transform 0s 0.4s; }
  body.elementor-default .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-mini-cart:not(.elementor-menu-cart--shown) .elementor-menu-cart__main {
    opacity: 0;
    -webkit-transform: translateY(-10px);
        -ms-transform: translateY(-10px);
            transform: translateY(-10px); }
  .elementor-edit-area-active .elementor-widget-woocommerce-menu-cart.elementor-widget.elementor-loading.elementor-menu-cart--shown {
    opacity: 1;
    /* This keeps mini-cart panels above other widgets so there's no flash when using the typography controls.
		The sticky setting in Elementor uses z-index 99 so we use 89 to keep it below sticky headers but above all other content
		and still allow 10 layers if 3rd party want to insert content between ours. */ }
    .elementor-edit-area-active .elementor-widget-woocommerce-menu-cart.elementor-widget.elementor-loading.elementor-menu-cart--shown .elementor-menu-cart__container {
      z-index: 9998; }
    .elementor-edit-area-active .elementor-widget-woocommerce-menu-cart.elementor-widget.elementor-loading.elementor-menu-cart--shown.elementor-menu-cart--cart-type-mini-cart {
      z-index: 89; }
  .elementor-widget-woocommerce-menu-cart.elementor-menu-cart--cart-type-dropdown .elementor-menu-cart__container {
    display: none; }

/* Select2 dropdown options are outside of the widget container */
.e-woo-select2-wrapper .select2-results__option {
  font-family: Roboto, sans-serif;
  font-size: 14px;
  color: #818a91; }
  .e-woo-select2-wrapper .select2-results__option:focus {
    color: #818a91; }

.elementor-widget-woocommerce-checkout-page {
  background-color: transparent;
  font-family: Roboto, sans-serif;
  font-size: 14px;
  line-height: 21px;
  color: #818a91;
  /* one column layout */
  /* override theme defaults for themes that have hover background colors on these elements. The hover background colors do not play well with the widget's initial design. */
  /* Make select2 appear like other inputs start */
  /* Make select2 appear like other inputs end */ }
  .elementor-widget-woocommerce-checkout-page.e-checkout-layout-one-column .e-checkout__container {
    grid-template-columns: auto; }
  .elementor-widget-woocommerce-checkout-page ::-webkit-input-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-checkout-page ::-moz-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-checkout-page ::-ms-input-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-checkout-page ::placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-checkout-page table tbody tr:hover > td,
  .elementor-widget-woocommerce-checkout-page table tbody tr:hover > th {
    background-color: transparent; }
  .elementor-widget-woocommerce-checkout-page .select2-container--default .select2-selection--single {
    color: var(--forms-fields-normal-color, #818a91);
    background-color: #f7f7f7;
    border-radius: var(--forms-fields-border-radius, 0px);
    border: none;
    height: 45px; }
    .elementor-widget-woocommerce-checkout-page .select2-container--default .select2-selection--single:focus {
      color: var(--forms-fields-focus-color, #818a91);
      background-color: #f7f7f7;
      border-color: var(--forms-fields-focus-border-color, initial);
      -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
           -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
              transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-checkout-page .select2-container--default .select2-selection--single .select2-selection__placeholder {
      color: var(--forms-fields-normal-color, #818a91); }
    .elementor-widget-woocommerce-checkout-page .select2-container--default .select2-selection--single .select2-selection__rendered {
      color: var(--forms-fields-normal-color, #818a91);
      line-height: 45px;
      padding-left: 1rem;
      padding-right: 1rem; }
    .elementor-widget-woocommerce-checkout-page .select2-container--default .select2-selection--single .select2-selection__arrow {
      height: 45px; }
  .elementor-widget-woocommerce-checkout-page .select2-container--open .select2-dropdown--below {
    background-color: #f7f7f7; }
  .elementor-widget-woocommerce-checkout-page .e-description {
    color: var(--sections-descriptions-color, #818a91);
    padding-bottom: var(--sections-descriptions-spacing, 0px);
    font-size: 14px;
    font-weight: 400; }
  .elementor-widget-woocommerce-checkout-page .e-woocommerce-login-section {
    margin-bottom: 24px; }
    .elementor-widget-woocommerce-checkout-page .e-woocommerce-login-section .e-checkout-secondary-title {
      text-align: var(--login-title-alignment, left); }
  .elementor-widget-woocommerce-checkout-page .e-woocommerce-login-nudge {
    margin-top: var(--sections-secondary-title-spacing, 24px);
    margin-bottom: 15px; }
  .elementor-widget-woocommerce-checkout-page .e-coupon-anchor {
    margin-top: var(--sections-secondary-title-spacing, 24px); }
  .elementor-widget-woocommerce-checkout-page .e-coupon-box {
    margin-top: 24px; }
  .elementor-widget-woocommerce-checkout-page .e-coupon-anchor-description {
    color: var(--forms-labels-color, #818a91);
    margin-bottom: var(--forms-label-spacing, 3px); }
  .elementor-widget-woocommerce-checkout-page .e-login-wrap {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center; }
    .elementor-widget-woocommerce-checkout-page .e-login-wrap-start {
      -webkit-box-flex: 75%;
          -ms-flex: 75%;
              flex: 75%; }
    .elementor-widget-woocommerce-checkout-page .e-login-wrap-end {
      -webkit-box-flex: 20%;
          -ms-flex: 20%;
              flex: 20%;
      text-align: right; }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-checkout-page .e-login-wrap {
        display: block; }
        .elementor-widget-woocommerce-checkout-page .e-login-wrap-end {
          text-align: left;
          margin-top: 15px; }
          .elementor-widget-woocommerce-checkout-page .e-login-wrap-end label.e-login-label {
            display: none; } }
  .elementor-widget-woocommerce-checkout-page .e-login-actions-wrap {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: justify;
        -ms-flex-pack: justify;
            justify-content: space-between;
    margin-top: 6px; }
    .elementor-widget-woocommerce-checkout-page .e-login-actions-wrap-end .lost_password {
      margin-bottom: 0;
      font-size: 12px; }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-checkout-page .e-login-actions-wrap-end .lost_password {
          font-size: 11px; } }
  .elementor-widget-woocommerce-checkout-page .e-apply-coupon {
    width: 90%;
    /* 90% to match the design */ }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-checkout-page .e-apply-coupon {
        width: auto; } }
  .elementor-widget-woocommerce-checkout-page .e-checkout__container {
    display: grid;
    -ms-flex-wrap: wrap;
        flex-wrap: wrap;
    grid-template-columns: 56% auto;
    /* column widths - to match the design */
    -webkit-box-align: stretch;
        -ms-flex-align: stretch;
            align-items: stretch;
    grid-column-gap: var(--sections-margin, 24px);
    grid-row-gap: var(--sections-margin, 24px); }
  @media (max-width: 1024px) {
    .elementor-widget-woocommerce-checkout-page .e-checkout__container {
      grid-template-columns: repeat(1, 1fr); } }
  .elementor-widget-woocommerce-checkout-page .e-checkout-secondary-title {
    color: var(--sections-secondary-title-color, #818a91);
    margin-bottom: 0; }
  .elementor-widget-woocommerce-checkout-page .e-woocommerce-coupon-nudge {
    text-align: var(--coupon-title-alignment, left); }
  .elementor-widget-woocommerce-checkout-page #ship-to-different-address {
    margin-top: 13px;
    padding-left: var(--shipping-heading-padding-start, 30px); }
    .elementor-widget-woocommerce-checkout-page #ship-to-different-address span {
      font-weight: 400; }
  .elementor-widget-woocommerce-checkout-page a {
    color: var(--links-normal-color, #5bc0de); }
    .elementor-widget-woocommerce-checkout-page a:hover {
      color: var(--links-hover-color, #5bc0de); }
  .elementor-widget-woocommerce-checkout-page .woocommerce {
    /* Need to use these specific selectors to override WooCommerce CSS */
    /* Need the <button> selector here so that we can target .woocommerce-button
		without being overwritten by WooCommerce's button.button selector.
		We are also targeting .woocommerce-button because none of this styling should
		apply to the Purchase button. Only The Login/Apply coupon button. */
    /* Main Sections styling start */
    /* Main Sections styling end */
    /* Styling for everything classified as 'Messages' start */
    /* Styling for everything classified as 'Messages' end */ }
    .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row {
      padding-left: var(--forms-columns-gap-padding, 0px);
      padding-right: var(--forms-columns-gap-padding, 0px);
      margin-left: var(--forms-columns-gap-margin, 0px);
      margin-right: var(--forms-columns-gap-margin, 0px); }
      .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row label,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row label,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row label {
        color: var(--forms-labels-color, #818a91);
        margin-bottom: var(--forms-label-spacing, 3px); }
      .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row .input-text,
      .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row select,
      .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row textarea,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row .input-text,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row select,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row textarea,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row .input-text,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row select,
      .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row textarea {
        color: var(--forms-fields-normal-color, #818a91);
        background-color: #f7f7f7;
        border-radius: var(--forms-fields-border-radius, 0px);
        padding: var(--forms-fields-padding, 16px);
        font-size: 14px;
        border: none;
        font-weight: 400; }
        .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row .input-text:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row select:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .form-row textarea:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row .input-text:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row select:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor .form-row textarea:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row .input-text:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row select:focus,
        .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row textarea:focus {
          color: var(--forms-fields-focus-color, #818a91);
          background-color: #f7f7f7;
          border-color: var(--forms-fields-focus-border-color, #818a91);
          -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
               -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
                  transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details #billing_address_1_field,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-anchor #billing_address_1_field,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box #billing_address_1_field {
      margin-bottom: 5px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .create-account,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box .form-row {
      /* need to use !important here to override the style controls,
			these items must not be affected by the controls */
      margin-bottom: 0 !important; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .input-radio,
    .elementor-widget-woocommerce-checkout-page .woocommerce #shipping_method li input {
      vertical-align: middle; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-form__input-checkbox {
      vertical-align: middle;
      margin: 0 5px 0 0; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-form__label-for-checkbox span {
      position: relative;
      top: 2px;
      color: var(--sections-checkboxes-color, #818a91); }
    .elementor-widget-woocommerce-checkout-page .woocommerce .wc_payment_method label,
    .elementor-widget-woocommerce-checkout-page .woocommerce #shipping_method li label {
      color: var(--sections-radio-buttons-color, #818a91); }
    .elementor-widget-woocommerce-checkout-page .woocommerce .wc_payment_method label {
      display: inline; }
    .elementor-widget-woocommerce-checkout-page .woocommerce button.woocommerce-button {
      background-color: #ffffff;
      color: var(--forms-buttons-normal-text-color, #6F6F6F);
      border-radius: var(--forms-buttons-border-radius, 3px);
      padding: 1rem;
      border-style: var(--forms-buttons-border-type, solid);
      border-color: var(--forms-buttons-border-color, #5bc0de);
      border-width: 2px; }
      .elementor-widget-woocommerce-checkout-page .woocommerce button.woocommerce-button:hover {
        color: var(--forms-buttons-hover-text-color, #6F6F6F);
        -webkit-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
                transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-checkout-page .woocommerce #coupon_code {
      margin-right: 1%; }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-checkout-page .woocommerce #coupon_code {
          width: 100%;
          margin-right: 0;
          margin-bottom: 15px; } }
    .elementor-widget-woocommerce-checkout-page .woocommerce-info {
      border-top-color: transparent;
      background-color: transparent;
      padding: 0; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-privacy-policy-text p {
      font-weight: 400;
      font-size: 12px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-form-login-toggle .woocommerce-info {
      font-weight: 400;
      margin-bottom: 0; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-woocommerce-login-section,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-checkout__order_review,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-coupon-box,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout #payment,
    .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .col-1,
    .elementor-widget-woocommerce-checkout-page .woocommerce .shipping_address,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-additional-fields {
      background: var(--sections-background-color, #ffffff);
      border-radius: var(--sections-border-radius, 3px);
      padding: var(--sections-padding, 16px 30px);
      margin: var(--sections-margin, 0 0 24px 0);
      border-style: var(--sections-border-type, solid);
      border-color: var(--sections-border-color, #D4D4D4);
      border-width: 1px;
      display: block; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-additional-fields {
      display: var(--additional-information-display, none); }
    @media (min-width: 1024px) {
      .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-additional-fields {
        margin: var(--sections-margin, 0); } }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout #payment .payment_box,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-privacy-policy-text,
    .elementor-widget-woocommerce-checkout-page .woocommerce .e-checkout-message {
      color: var(--sections-messages-color, #818a91);
      font-weight: 400; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-privacy-policy-text p {
      margin-top: 25px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .col2-set .col-1 {
      margin-bottom: 0; }
    .elementor-widget-woocommerce-checkout-page .woocommerce #customer_details .col2-set .col-2 {
      padding-top: 15px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce #order_review_heading {
      text-align: var(--order-review-title-alignment, left); }
    .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table {
      margin-bottom: 0;
      border: 0;
      font-size: 14px; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table thead {
        background-color: transparent; }
        .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table thead tr th {
          padding-top: 0; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tbody td {
        color: #000000; }
        .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tbody td .product-quantity {
          font-weight: normal; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tfoot th,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tfoot td {
        color: #818a91; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table td,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tr,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table th {
        border: 0;
        padding-left: 0;
        padding-bottom: 15px;
        padding-top: 15px; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table .order-total th,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table .order-total tr,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table .order-total td {
        padding-bottom: 0; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tr:nth-child(odd) > td,
      .elementor-widget-woocommerce-checkout-page .woocommerce .shop_table tr:nth-child(odd) > th {
        background-color: transparent; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table .cart_item td {
      font-weight: 400;
      color: var(--order-summary-items-color, #000000);
      border-bottom-color: var(--order-summary-items-divider-color, #818a91);
      border-bottom-width: var(--order-summary-items-divider-weight, 0px);
      border-bottom-style: solid; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table .cart_item td.product-name {
        padding-right: 40px;
        max-width: 150px; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table .cart_item td.product-total {
        vertical-align: top; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table td,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table th {
      padding-top: var(--order-summary-rows-gap-top, 15px);
      padding-bottom: var(--order-summary-rows-gap-bottom, 15px); }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table thead th,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table tfoot td,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table tfoot th {
      color: var(--order-summary-totals-color, #818a91);
      vertical-align: top; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table .order-total td,
    .elementor-widget-woocommerce-checkout-page .woocommerce .woocommerce-checkout-review-order-table .order-total th {
      border-top-color: var(--order-summary-totals-divider-color, #818a91);
      border-top-width: var(--order-summary-totals-divider-weight, 0px);
      border-top-style: solid; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-shipping-totals td {
      max-width: 70px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce h3 {
      font-size: 14px;
      font-weight: 700;
      margin-top: 0;
      margin-bottom: var(--sections-title-spacing, 30px);
      color: var(--sections-title-color, #000000); }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row > span {
      font-weight: 400;
      font-size: 14px;
      margin-bottom: 3px;
      color: #818a91; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row-first, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row-last {
      /* use 48% to match the design. Default WC CSS uses 47% */
      width: 48%; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row .input-checkbox {
      vertical-align: middle;
      margin: 0 5px 0 0; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-billing-fields h3 {
      text-align: var(--billing-details-title-alignment, left); }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-billing-fields .form-row, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-shipping-fields .form-row, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-account-fields .form-row {
      margin-bottom: var(--forms-rows-gap, 5px); }
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-billing-fields .form-row:last-child, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-shipping-fields .form-row:last-child, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .woocommerce-account-fields .form-row:last-child {
        margin-bottom: 15px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout.login {
      margin-top: -8px;
      z-index: 999;
      background: #ffffff;
      border-top-width: 0;
      position: relative;
      margin-bottom: 0;
      color: #818a91; }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row-first, .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .form-row-last {
        width: 100%; } }
    .elementor-widget-woocommerce-checkout-page .woocommerce-form-coupon-toggle {
      display: none; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-form-login__submit {
      width: 85%;
      /* 85% to match the design */ }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-checkout-page .woocommerce-form-login__submit {
          width: 35%;
          /* 35% to match the design */ } }
    .elementor-widget-woocommerce-checkout-page .woocommerce-additional-fields h3 {
      background: var(--additional-fields-title-alignment, left); }
    .elementor-widget-woocommerce-checkout-page .woocommerce-shipping-fields .shipping_address {
      margin-bottom: var(--sections-margin, 20px); }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment {
      margin-top: 24px;
      padding: 15px 25px 25px; }
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods {
        border-bottom: none;
        padding: 0; }
        .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods .payment_box {
          background-color: #f7f7f7; }
          .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods .payment_box:before {
            display: none; }
        .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods li {
          line-height: 21px; }
          .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods li label a {
            padding-left: 15px;
            font-size: 12px; }
            @media (max-width: 1024px) {
              .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods li label a {
                float: none;
                font-size: 11px;
                padding-left: 10px; } }
          @media (max-width: 1024px) {
            .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .payment_methods li label img {
              width: 55px;
              /* 55px to match the design */ } }
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .place-order {
        display: -webkit-box;
        display: -ms-flexbox;
        display: flex;
        -webkit-box-orient: vertical;
        -webkit-box-direction: normal;
            -ms-flex-direction: column;
                flex-direction: column;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap;
        padding: 0;
        margin-bottom: 0;
        -webkit-box-align: var(--place-order-title-alignment, stretch);
            -ms-flex-align: var(--place-order-title-alignment, stretch);
                align-items: var(--place-order-title-alignment, stretch); }
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment #place_order {
        background-color: #5bc0de;
        width: var(--purchase-button-width, auto);
        float: none;
        color: var(--purchase-button-normal-text-color, #ffffff);
        min-height: auto;
        padding: var(--purchase-button-padding, 1em 1em);
        border-radius: var(--purchase-button-border-radius, 3px); }
        .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment #place_order:hover {
          background-color: #5bc0de;
          color: var(--purchase-button-hover-text-color, #ffffff);
          border-color: var(--purchase-button-hover-border-color, #5bc0de);
          -webkit-transition-duration: var(--purchase-button-hover-transition-duration, 0.3s);
               -o-transition-duration: var(--purchase-button-hover-transition-duration, 0.3s);
                  transition-duration: var(--purchase-button-hover-transition-duration, 0.3s); }
      .elementor-widget-woocommerce-checkout-page .woocommerce-checkout #payment .woocommerce-info:before {
        display: none; }
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .col2-set .col-1,
    .elementor-widget-woocommerce-checkout-page .woocommerce-checkout .col2-set .col-2 {
      width: auto;
      float: none; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .coupon-container-grid {
      display: grid;
      grid-template-columns: auto auto;
      /*columns widths*/
      -webkit-box-align: center;
          -ms-flex-align: center;
              align-items: center; }
      .elementor-widget-woocommerce-checkout-page .woocommerce .coupon-container-grid .coupon-col-2 {
        text-align: right; }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-checkout-page .woocommerce .coupon-container-grid {
          display: block; }
          .elementor-widget-woocommerce-checkout-page .woocommerce .coupon-container-grid .coupon-col-2 {
            text-align: left; } }
    .elementor-widget-woocommerce-checkout-page .woocommerce #account_password_field {
      /* need to override the style controls,
			these items must not be affected by the controls */
      margin-bottom: 10px; }
    .elementor-widget-woocommerce-checkout-page .woocommerce .product-name .variation {
      color: var(--order-summary-variations-color, #000000);
      /* We need to specify these values so that the 'Items' Typography control does not affect
			the 'Variations' */
      font-size: 14px;
      font-style: normal;
      text-transform: none;
      letter-spacing: normal;
      text-decoration: none;
      line-height: 21px; }

/* Select2 dropdown options are outside of the widget container */
.e-woo-select2-wrapper .select2-results__option {
  font-family: Roboto, sans-serif;
  font-size: 14px;
  color: #818a91; }
  .e-woo-select2-wrapper .select2-results__option:focus {
    color: #818a91; }

.elementor-widget-woocommerce-cart {
  /* one column layout */
  /* Make select2 appear like other inputs start */
  /* Make select2 appear like other inputs end */ }
  .elementor-widget-woocommerce-cart.e-cart-layout-one-column .e-cart__container {
    grid-template-columns: auto; }
  .elementor-widget-woocommerce-cart table tbody tr:hover > td,
  .elementor-widget-woocommerce-cart table tbody tr:hover > th {
    background-color: inherit; }
  .elementor-widget-woocommerce-cart .e {
    /* .e-clear is a class that is added between the cart sections to fix collapsing margins,
		especially when custom margins are being set by the Style Controls, then the margins could
		start overriding the other margin, leaving one margin */ }
    .elementor-widget-woocommerce-cart .e-clear {
      overflow: hidden;
      height: 0;
      width: 0; }
    .elementor-widget-woocommerce-cart .e-cart {
      /* Main sections styling start */
      /* Main sections styling end */
      /* one column layout */ }
      .elementor-widget-woocommerce-cart .e-cart-section {
        background-color: var(--sections-background-color, #ffffff);
        padding: var(--sections-padding, 16px 30px);
        margin: var(--sections-margin, 0 0 30px 0);
        border-radius: var(--sections-border-radius, 3px);
        border-width: 1px;
        border-style: var(--sections-border-type, solid);
        border-color: var(--sections-border-color, #D4D4D4); }
      @media (min-width: 1024px) {
        .elementor-widget-woocommerce-cart .e-cart-section:last-child {
          margin: var(--sections-margin, 0); } }
      .elementor-widget-woocommerce-cart .e-cart-content {
        color: var(--sections-descriptions-color, #818a91);
        font-size: 15px;
        font-weight: 400;
        line-height: 23px;
        letter-spacing: 0; }
      .elementor-widget-woocommerce-cart .e-cart__container {
        display: grid;
        -ms-flex-wrap: wrap;
            flex-wrap: wrap;
        grid-template-columns: 59% auto;
        /* 59% to match the required design */
        -webkit-box-align: stretch;
            -ms-flex-align: stretch;
                align-items: stretch;
        grid-column-gap: var(--sections-margin, 30px);
        grid-row-gap: var(--sections-margin, 30px); }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-cart .e-cart__container {
          grid-template-columns: repeat(1, 1fr); } }
      .elementor-widget-woocommerce-cart .e-cart-layout-one-column .e-cart__container {
        grid-template-columns: auto; }
  .elementor-widget-woocommerce-cart .select2-container {
    margin-bottom: 4px; }
    .elementor-widget-woocommerce-cart .select2-container--default .select2-selection--single {
      color: var(--forms-fields-normal-color, #818a91);
      background-color: #f7f7f7;
      border-radius: var(--forms-fields-border-radius, 0px);
      border: none;
      height: 45px; }
      .elementor-widget-woocommerce-cart .select2-container--default .select2-selection--single:focus {
        color: var(--forms-fields-focus-color, #818a91);
        background-color: #f7f7f7;
        border-color: var(--forms-fields-focus-border-color, initial);
        -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
                transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
      .elementor-widget-woocommerce-cart .select2-container--default .select2-selection--single .select2-selection__placeholder {
        color: var(--forms-fields-normal-color, #818a91); }
      .elementor-widget-woocommerce-cart .select2-container--default .select2-selection--single .select2-selection__rendered {
        color: var(--forms-fields-normal-color, #818a91);
        line-height: 45px;
        padding-left: 1rem;
        padding-right: 1rem; }
      .elementor-widget-woocommerce-cart .select2-container--default .select2-selection--single .select2-selection__arrow {
        height: 45px; }
    .elementor-widget-woocommerce-cart .select2-container--open .select2-dropdown--below {
      background-color: #f7f7f7; }
  .elementor-widget-woocommerce-cart .woocommerce {
    font-family: Roboto, sans-serif; }
    .elementor-widget-woocommerce-cart .woocommerce button.button {
      background-color: #ffffff;
      color: var(--forms-buttons-normal-text-color, #818a91);
      border-radius: var(--forms-buttons-border-radius, 3px);
      /* 0.88rem is used here so that this button will match the design layout from Product. */
      padding: var(--forms-buttons-padding, 0.88rem 2rem);
      width: var(--forms-buttons-width, auto);
      border-style: var(--forms-buttons-border-type, solid);
      border-color: var(--forms-buttons-border-color, #5bc0de);
      border-width: 2px; }
      .elementor-widget-woocommerce-cart .woocommerce button.button:hover {
        color: var(--forms-buttons-hover-text-color, #818a91);
        -webkit-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
                transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
        border-color: var(--forms-buttons-hover-border-color, #5bc0de); }
      .elementor-widget-woocommerce-cart .woocommerce button.button.disabled, .elementor-widget-woocommerce-cart .woocommerce button.button:disabled, .elementor-widget-woocommerce-cart .woocommerce button.button:disabled[disabled] {
        /* 0.88rem is used here so that this button will match the design layout from Product. */
        padding: var(--forms-buttons-padding, 0.88rem 2rem);
        color: var(--forms-buttons-normal-text-color, #818a91); }
        .elementor-widget-woocommerce-cart .woocommerce button.button.disabled:hover, .elementor-widget-woocommerce-cart .woocommerce button.button:disabled:hover, .elementor-widget-woocommerce-cart .woocommerce button.button:disabled[disabled]:hover {
          background-color: var(--forms-buttons-hover-background-color, #ffffff);
          color: var(--forms-buttons-hover-text-color, #818a91);
          -webkit-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
               -o-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
                  transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
          border-color: var(--forms-buttons-hover-border-color, #5bc0de); }
    .elementor-widget-woocommerce-cart .woocommerce #shipping_method li label {
      color: var(--sections-radio-buttons-color, #818a91); }
    .elementor-widget-woocommerce-cart .woocommerce #shipping_method li input {
      vertical-align: middle; }
    .elementor-widget-woocommerce-cart .woocommerce .shipping-calculator-form {
      margin-top: var(--sections-descriptions-spacing, 15px); }
    .elementor-widget-woocommerce-cart .woocommerce .woocommerce-shipping-destination {
      color: var(--sections-descriptions-color, #818a91);
      margin-bottom: 0; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table_responsive tbody th, .elementor-widget-woocommerce-cart .woocommerce-page .cart_totals table.shop_table_responsive tbody th {
      display: none; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table_responsive tr.woocommerce-shipping-totals td, .elementor-widget-woocommerce-cart .woocommerce-page .cart_totals table.shop_table_responsive tr.woocommerce-shipping-totals td {
      text-align: left !important;
      /* need important here because Woo also has !important */ }
      .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table_responsive tr.woocommerce-shipping-totals td::before, .elementor-widget-woocommerce-cart .woocommerce-page .cart_totals table.shop_table_responsive tr.woocommerce-shipping-totals td::before {
        width: 100%;
        margin-bottom: 10px; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table_responsive tr td, .elementor-widget-woocommerce-cart .woocommerce-page .cart_totals table.shop_table_responsive tr td {
      text-align: right !important;
      /* need important here because Woo also has !important */ }
      .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table_responsive tr td::before, .elementor-widget-woocommerce-cart .woocommerce-page .cart_totals table.shop_table_responsive tr td::before {
        content: attr(data-title);
        font-weight: 700;
        float: left; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals h2 {
      text-align: var(--totals-title-alignment, left); }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table td {
      padding-top: var(--totals-rows-gap-top, 12px);
      padding-bottom: var(--totals-rows-gap-bottom, 9px); }
      .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table td:before,
      .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table td .woocommerce-Price-amount {
        color: var(--totals-color, #818a91);
        font-weight: 700; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals table.shop_table tr.order-total td {
      border-top-color: var(--totals-divider-color, #818a91);
      border-top-width: var(--totals-divider-weight, 0); }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals .form-row {
      margin-bottom: var(--forms-rows-gap, 6px); }
    .elementor-widget-woocommerce-cart .woocommerce .product-name a {
      color: var(--product-link-normal-color, #000000); }
      .elementor-widget-woocommerce-cart .woocommerce .product-name a:hover {
        color: var(--product-link-hover-color, #000000); }
    .elementor-widget-woocommerce-cart .woocommerce .form-row {
      padding: 3px 0;
      margin: 0; }
    .elementor-widget-woocommerce-cart .woocommerce .input-text,
    .elementor-widget-woocommerce-cart .woocommerce select {
      color: var(--forms-fields-normal-color, #818a91);
      background-color: #f7f7f7;
      border-radius: var(--forms-fields-border-radius, 3px);
      border: none;
      padding: var(--forms-fields-padding, 16px);
      font-size: 14px; }
      .elementor-widget-woocommerce-cart .woocommerce .input-text::-webkit-input-placeholder,
      .elementor-widget-woocommerce-cart .woocommerce select::-webkit-input-placeholder {
        color: var(--forms-fields-normal-color, inherit);
        font-family: inherit;
        opacity: .6; }
      .elementor-widget-woocommerce-cart .woocommerce .input-text::-moz-placeholder,
      .elementor-widget-woocommerce-cart .woocommerce select::-moz-placeholder {
        color: var(--forms-fields-normal-color, inherit);
        font-family: inherit;
        opacity: .6; }
      .elementor-widget-woocommerce-cart .woocommerce .input-text::-ms-input-placeholder,
      .elementor-widget-woocommerce-cart .woocommerce select::-ms-input-placeholder {
        color: var(--forms-fields-normal-color, inherit);
        font-family: inherit;
        opacity: .6; }
      .elementor-widget-woocommerce-cart .woocommerce .input-text::placeholder,
      .elementor-widget-woocommerce-cart .woocommerce select::placeholder {
        color: var(--forms-fields-normal-color, inherit);
        font-family: inherit;
        opacity: .6; }
      .elementor-widget-woocommerce-cart .woocommerce .input-text:focus,
      .elementor-widget-woocommerce-cart .woocommerce select:focus {
        color: var(--forms-fields-focus-color, #818a91);
        background-color: #f7f7f7;
        border-color: var(--forms-fields-focus-border-color, transparent);
        -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
                transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
        .elementor-widget-woocommerce-cart .woocommerce .input-text:focus::-webkit-input-placeholder,
        .elementor-widget-woocommerce-cart .woocommerce select:focus::-webkit-input-placeholder {
          color: var(--forms-fields-focus-color, #818a91); }
        .elementor-widget-woocommerce-cart .woocommerce .input-text:focus::-moz-placeholder,
        .elementor-widget-woocommerce-cart .woocommerce select:focus::-moz-placeholder {
          color: var(--forms-fields-focus-color, #818a91); }
        .elementor-widget-woocommerce-cart .woocommerce .input-text:focus::-ms-input-placeholder,
        .elementor-widget-woocommerce-cart .woocommerce select:focus::-ms-input-placeholder {
          color: var(--forms-fields-focus-color, #818a91); }
        .elementor-widget-woocommerce-cart .woocommerce .input-text:focus::placeholder,
        .elementor-widget-woocommerce-cart .woocommerce select:focus::placeholder {
          color: var(--forms-fields-focus-color, #818a91); }
    .elementor-widget-woocommerce-cart .woocommerce .input-text.qty {
      background-color: transparent;
      color: var(--order-summary-color, #000000);
      border-width: var(--order-summary-quantity-border-weight, 1px);
      border-style: solid;
      border-color: var(--order-summary-quantity-border-color, #D4D4D4);
      border-radius: 3px;
      padding: 1px 2px;
      text-align: left;
      font-size: 14px;
      min-height: 28px;
      max-height: 28px; }
    .elementor-widget-woocommerce-cart .woocommerce .wc-proceed-to-checkout {
      padding-bottom: 0;
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex;
      -webkit-box-orient: vertical;
      -webkit-box-direction: normal;
          -ms-flex-direction: column;
              flex-direction: column;
      -ms-flex-wrap: wrap;
          flex-wrap: wrap;
      -webkit-box-align: var(--place-order-title-alignment, stretch);
          -ms-flex-align: var(--place-order-title-alignment, stretch);
              align-items: var(--place-order-title-alignment, stretch); }
      .elementor-widget-woocommerce-cart .woocommerce .wc-proceed-to-checkout .checkout-button {
        padding: var(--checkout-button-padding, 15px 1em);
        width: var(--checkout-button-width, auto);
        font-size: 15px;
        text-align: center;
        color: var(--checkout-button-normal-text-color, #ffffff);
        background-color: #5bc0de;
        border-radius: var(--checkout-button-border-radius, 3px);
        min-height: auto;
        margin-bottom: 0; }
        .elementor-widget-woocommerce-cart .woocommerce .wc-proceed-to-checkout .checkout-button:hover {
          color: var(--checkout-button-hover-text-color, #ffffff);
          background-color: #5bc0de;
          border-color: var(--checkout-button-hover-border-color, #5bc0de);
          -webkit-transition-duration: var(--checkout-button-hover-transition-duration, 0.3s);
               -o-transition-duration: var(--checkout-button-hover-transition-duration, 0.3s);
                  transition-duration: var(--checkout-button-hover-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-cart .woocommerce .remove {
      background: transparent;
      color: var(--order-summary-remove-icon-normal-color, #000000) !important;
      /* need important here because Woo also has !important */
      width: auto; }
      .elementor-widget-woocommerce-cart .woocommerce .remove:hover {
        background: transparent;
        color: var(--order-summary-remove-icon-hover-color, #5bc0de) !important;
        /* need important here because Woo also has !important */ }
    .elementor-widget-woocommerce-cart .woocommerce .cart-collaterals .cart_totals {
      float: none;
      width: 100%; }
      .elementor-widget-woocommerce-cart .woocommerce .cart-collaterals .cart_totals td {
        padding-left: 0; }
      .elementor-widget-woocommerce-cart .woocommerce .cart-collaterals .cart_totals .woocommerce-shipping-totals td {
        padding-right: 0; }
    .elementor-widget-woocommerce-cart .woocommerce .coupon .button {
      float: right;
      width: 100%; }
    .elementor-widget-woocommerce-cart .woocommerce .coupon .form-row {
      padding: 0; }
    .elementor-widget-woocommerce-cart .woocommerce .coupon-col {
      display: -webkit-box;
      display: -ms-flexbox;
      display: flex; }
      .elementor-widget-woocommerce-cart .woocommerce .coupon-col-start {
        -webkit-box-flex: 2;
            -ms-flex: 2;
                flex: 2;
        padding-right: 30px; }
        @media (max-width: 1024px) {
          .elementor-widget-woocommerce-cart .woocommerce .coupon-col-start {
            padding-right: 0; } }
      .elementor-widget-woocommerce-cart .woocommerce .coupon-col-end {
        -webkit-box-flex: 1;
            -ms-flex: 1;
                flex: 1; }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-cart .woocommerce .coupon-col {
          display: block; } }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-cart .woocommerce .coupon {
        margin: var(--sections-margin, 0); }
        .elementor-widget-woocommerce-cart .woocommerce .coupon #coupon_code {
          width: 100%;
          margin-right: 0;
          margin-bottom: 15px; }
        .elementor-widget-woocommerce-cart .woocommerce .coupon .button {
          width: 100%; } }
    .elementor-widget-woocommerce-cart .woocommerce table.shop_table {
      border: 0 solid; }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table .button {
        float: left;
        font-size: 14px;
        font-weight: 700; }
      @media (max-width: 1024px) {
        .elementor-widget-woocommerce-cart .woocommerce table.shop_table .button {
          float: none;
          width: 100%; } }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table td,
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table tr,
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table th {
        border: 0 solid; }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table tr:nth-child(odd) > td,
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table tr:nth-child(odd) > th {
        background-color: transparent; }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table .actions {
        padding: 16px 0 0; }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table .product-remove a {
        display: inline-block; }
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table.cart tbody tr:last-child {
        display: var(--update-cart-automatically-display, table-row); }
    .elementor-widget-woocommerce-cart .woocommerce table.cart {
      margin-bottom: 0; }
      .elementor-widget-woocommerce-cart .woocommerce table.cart img {
        width: 55px;
        height: auto;
        display: block; }
      .elementor-widget-woocommerce-cart .woocommerce table.cart td {
        padding-top: var(--order-summary-rows-gap-top, 20px);
        padding-right: 20px;
        padding-bottom: var(--order-summary-rows-gap-bottom, 20px);
        padding-left: 0; }
        .elementor-widget-woocommerce-cart .woocommerce table.cart td span {
          color: var(--order-summary-color, #000000);
          font-size: 14px;
          font-weight: 400; }
        .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-remove, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-thumbnail, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-name, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-price, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-quantity, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-subtotal, .elementor-widget-woocommerce-cart .woocommerce table.cart td.actions {
          border-top-width: var(--order-summary-items-divider-weight, 1px);
          border-top-style: solid;
          border-top-color: var(--order-summary-items-divider-color, #D4D4D4); }
          @media (max-width: 768px) {
            .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-remove, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-thumbnail, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-name, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-price, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-quantity, .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-subtotal, .elementor-widget-woocommerce-cart .woocommerce table.cart td.actions {
              border-top-width: 0; } }
        .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-remove {
          padding-left: 0;
          padding-right: 0; }
      @media (min-width: 767px) {
        .elementor-widget-woocommerce-cart .woocommerce table.cart tbody tr:first-child td {
          border-top: none; } }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-cart .woocommerce table.cart.product-remove {
        position: relative; }
      .elementor-widget-woocommerce-cart .woocommerce table.cart.product-name {
        padding-right: 0; }
      .elementor-widget-woocommerce-cart .woocommerce table.cart tr {
        border-top-width: var(--order-summary-items-divider-weight, 1px);
        border-top-color: var(--order-summary-items-divider-color, #D4D4D4); }
        .elementor-widget-woocommerce-cart .woocommerce table.cart tr:first-child {
          border-top: none; } }
    @media (max-width: 768px) {
      .elementor-widget-woocommerce-cart .woocommerce table.cart td {
        padding-left: 0;
        padding-right: 0; } }
    @media (max-width: 767px) {
      .elementor-widget-woocommerce-cart .woocommerce table.cart {
        padding: 0; }
        .elementor-widget-woocommerce-cart .woocommerce table.cart tr {
          padding: 16px 28px; }
          .elementor-widget-woocommerce-cart .woocommerce table.cart tr:first-child {
            border-top: none; }
        .elementor-widget-woocommerce-cart .woocommerce table.cart td {
          padding-left: 0;
          padding-right: 0; }
          .elementor-widget-woocommerce-cart .woocommerce table.cart td:first-child {
            border-top: none; }
          .elementor-widget-woocommerce-cart .woocommerce table.cart td.product-name {
            border-top: none; }
          .elementor-widget-woocommerce-cart .woocommerce table.cart td.actions {
            padding: 0; } }
    .elementor-widget-woocommerce-cart .woocommerce a {
      color: var(--links-normal-color, #5bc0de); }
      .elementor-widget-woocommerce-cart .woocommerce a:hover {
        color: var(--links-hover-color, #5bc0de); }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals h2,
    .elementor-widget-woocommerce-cart .woocommerce .cart th {
      font-size: 14px;
      font-weight: 700;
      margin-top: 0;
      padding-top: 0;
      padding-bottom: 8px;
      padding-left: 0;
      padding-right: 20px; }
    .elementor-widget-woocommerce-cart .woocommerce .cart_totals h2 {
      margin-bottom: var(--sections-title-spacing, 1rem);
      color: var(--sections-title-color, #000000); }
    .elementor-widget-woocommerce-cart .woocommerce .cart th {
      padding-bottom: var(--order-summary-title-spacing, 8px);
      color: var(--order-summary-title-color, #000000); }
    .elementor-widget-woocommerce-cart .woocommerce .cart td::before {
      color: var(--order-summary-title-color, #000000); }
    .elementor-widget-woocommerce-cart .woocommerce .shipping-calculator-button::after {
      display: none; }
    .elementor-widget-woocommerce-cart .woocommerce .product-name .variation {
      color: var(--order-summary-variations-color, #000000); }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-cart .woocommerce table.shop_table_responsive tr:nth-child(2n) td, .elementor-widget-woocommerce-cart .woocommerce-page table.shop_table_responsive tr:nth-child(2n) td {
        background-color: transparent; }
      .elementor-widget-woocommerce-cart .woocommerce .cart_totals .shop_table_responsive td {
        padding-left: 0; } }

/* Select2 dropdown options are outside of the widget container */
.e-woo-select2-wrapper .select2-results__option {
  font-family: Roboto, sans-serif;
  font-size: 14px;
  color: var(--forms-fields-normal-color, #818a91); }
  .e-woo-select2-wrapper .select2-results__option:focus {
    color: var(--forms-fields-focus-color, #818a91);
    border-color: var(--forms-fields-focus-border-color, #818a91);
    -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
         -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
            transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }

.elementor-widget-woocommerce-my-account {
  font-family: Roboto, sans-serif;
  color: #818a91;
  /* Make select2 appear like other inputs start */
  /* Make select2 appear like other inputs end */ }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__dashboard .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__orders .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__downloads .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-account .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-address .woocommerce-MyAccount-content-wrapper {
    border-style: var(--sections-border-type, solid);
    border-color: var(--sections-border-color, #D4D4D4);
    border-width: 1px;
    border-radius: var(--sections-border-radius, 3px); }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__dashboard .shop_table, .elementor-widget-woocommerce-my-account .e-my-account-tab__orders .shop_table, .elementor-widget-woocommerce-my-account .e-my-account-tab__downloads .shop_table, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-account .shop_table, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-address .shop_table {
    border: none;
    margin-bottom: 0; }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__dashboard .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__orders .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__downloads .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-account .woocommerce-MyAccount-content-wrapper {
    background-color: var(--sections-background-color, #ffffff); }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__dashboard .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-account .woocommerce-MyAccount-content-wrapper {
    padding: var(--sections-padding, 16px 30px); }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__orders .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__downloads .woocommerce-MyAccount-content-wrapper {
    padding: var(--sections-padding, 16px 30px 3px 30px); }
  .elementor-widget-woocommerce-my-account .e-my-account-tab .woocommerce-address-fields,
  .elementor-widget-woocommerce-my-account .e-my-account-tab address {
    background-color: var(--sections-background-color, #ffffff);
    padding: var(--sections-padding, 16px 30px);
    border-style: var(--sections-border-type, solid);
    border-color: var(--sections-border-color, #D4D4D4);
    border-width: 1px;
    border-radius: var(--sections-border-radius, 3px); }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .woocommerce-MyAccount-content, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-address .woocommerce-MyAccount-content {
    border: 0; }
    .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .woocommerce-MyAccount-content-wrapper, .elementor-widget-woocommerce-my-account .e-my-account-tab__edit-address .woocommerce-MyAccount-content-wrapper {
      padding: 0;
      border: 0; }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .order_details {
    margin-bottom: 40px; }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .woocommerce-table--order-downloads,
  .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .order_details {
    background-color: var(--sections-background-color, #ffffff);
    padding: var(--sections-padding, 16px 30px 3px 30px);
    border-style: var(--sections-border-type, solid);
    border-color: var(--sections-border-color, #D4D4D4);
    border-width: 1px;
    border-radius: var(--sections-border-radius, 3px); }
  .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content > div > p {
    color: var(--general-text-color, #818a91); }
  .elementor-widget-woocommerce-my-account .select2-container--default .select2-selection--single {
    color: var(--forms-fields-normal-color, #818a91);
    background-color: var(--forms-fields-normal-background-color, #f7f7f7);
    border-radius: var(--forms-fields-border-radius, 0px);
    border: none;
    height: 45px; }
    .elementor-widget-woocommerce-my-account .select2-container--default .select2-selection--single:focus {
      color: var(--forms-fields-focus-color, #818a91);
      background-color: var(--forms-fields-focus-background-color, #f7f7f7);
      border-color: var(--forms-fields-focus-border-color, initial);
      -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
           -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
              transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-my-account .select2-container--default .select2-selection--single .select2-selection__placeholder {
      color: var(--forms-fields-normal-color, #818a91); }
    .elementor-widget-woocommerce-my-account .select2-container--default .select2-selection--single .select2-selection__rendered {
      color: var(--forms-fields-normal-color, #818a91);
      line-height: 45px;
      padding-left: 1rem;
      padding-right: 1rem; }
    .elementor-widget-woocommerce-my-account .select2-container--default .select2-selection--single .select2-selection__arrow {
      height: 45px; }
  .elementor-widget-woocommerce-my-account .select2-container--open .select2-dropdown--below {
    background-color: var(--forms-fields-normal-background-color, #f7f7f7); }
  .elementor-widget-woocommerce-my-account .woocommerce ::-webkit-input-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-my-account .woocommerce ::-moz-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-my-account .woocommerce ::-ms-input-placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-my-account .woocommerce ::placeholder {
    color: var(--forms-fields-normal-color, inherit);
    font-family: inherit;
    opacity: .6; }
  .elementor-widget-woocommerce-my-account .woocommerce-message {
    font-size: 14px; }
  .elementor-widget-woocommerce-my-account .woocommerce address {
    color: var(--general-text-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce a {
    color: var(--links-normal-color, #5bc0de); }
    .elementor-widget-woocommerce-my-account .woocommerce a:hover {
      color: var(--links-hover-color, #5bc0de); }
    .elementor-widget-woocommerce-my-account .woocommerce a.button.alt:hover {
      background-color: initial; }
    .elementor-widget-woocommerce-my-account .woocommerce a.button:hover {
      background-color: initial; }
  .elementor-widget-woocommerce-my-account .woocommerce em {
    font-size: 12px;
    color: var(--login-messages-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce .form-row {
    padding-left: var(--forms-columns-gap-padding-left, 0px);
    padding-right: var(--forms-columns-gap-padding-right, 0px);
    margin-left: var(--forms-columns-gap-margin-left, 0px);
    margin-right: var(--forms-columns-gap-margin-right, 0px);
    margin-bottom: var(--forms-rows-gap, 6px); }
    .elementor-widget-woocommerce-my-account .woocommerce .form-row label {
      color: var(--forms-labels-color, #818a91);
      margin-bottom: var(--forms-label-spacing, 0px); }
    .elementor-widget-woocommerce-my-account .woocommerce .form-row .input-text,
    .elementor-widget-woocommerce-my-account .woocommerce .form-row select {
      color: var(--forms-fields-normal-color, #818a91);
      border-radius: var(--forms-fields-border-radius, 0px);
      padding: var(--forms-fields-padding, 16px);
      background: #f7f7f7;
      border: none;
      font-size: 14px; }
      .elementor-widget-woocommerce-my-account .woocommerce .form-row .input-text:focus,
      .elementor-widget-woocommerce-my-account .woocommerce .form-row select:focus {
        color: var(--forms-fields-focus-color, #818a91);
        border-color: var(--forms-fields-focus-border-color, #818a91);
        -webkit-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-fields-focus-transition-duration, 0.3s);
                transition-duration: var(--forms-fields-focus-transition-duration, 0.3s); }
  .elementor-widget-woocommerce-my-account .woocommerce #billing_address_1_field {
    margin-bottom: 5px; }
  .elementor-widget-woocommerce-my-account .woocommerce .login .woocommerce-privacy-policy-text,
  .elementor-widget-woocommerce-my-account .woocommerce .register .woocommerce-privacy-policy-text {
    margin-bottom: 15px;
    color: var(--login-messages-color, #818a91);
    font-size: 12px; }
  .elementor-widget-woocommerce-my-account .woocommerce .login p:nth-child(2),
  .elementor-widget-woocommerce-my-account .woocommerce .register p:nth-child(2) {
    color: var(--login-messages-color, #818a91);
    font-size: 12px; }
  .elementor-widget-woocommerce-my-account .woocommerce .login .woocommerce-LostPassword,
  .elementor-widget-woocommerce-my-account .woocommerce .register .woocommerce-LostPassword {
    font-size: 12px;
    margin-bottom: 0px; }
  .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword {
    width: 50%;
    /* 50% to match the design - it would normally be full width */ }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword {
        width: 100%; } }
    .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword p {
      color: var(--general-text-color, #818a91); }
    .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword .form-row-first {
      width: 100%; }
  .elementor-widget-woocommerce-my-account .woocommerce .login,
  .elementor-widget-woocommerce-my-account .woocommerce .register,
  .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword {
    background-color: var(--sections-background-color, #ffffff);
    padding: var(--sections-padding, 16px 30px);
    border-style: var(--sections-border-type, solid);
    border-color: var(--sections-border-color, #D4D4D4);
    border-width: 1px;
    border-radius: var(--sections-border-radius, 3px);
    font-size: 14px; }
    .elementor-widget-woocommerce-my-account .woocommerce .login .button,
    .elementor-widget-woocommerce-my-account .woocommerce .register .button,
    .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword .button {
      background: #5bc0de;
      border: none;
      color: var(--forms-buttons-normal-text-color, #ffffff);
      border-radius: var(--forms-buttons-border-radius, 3px);
      padding: var(--forms-buttons-padding, 12px 32px); }
      .elementor-widget-woocommerce-my-account .woocommerce .login .button:hover,
      .elementor-widget-woocommerce-my-account .woocommerce .register .button:hover,
      .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-ResetPassword .button:hover {
        color: var(--forms-buttons-hover-text-color, #ffffff);
        -webkit-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
             -o-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
                transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s); }
  .elementor-widget-woocommerce-my-account .woocommerce .login p:nth-child(3) {
    margin-top: 20px; }
  .elementor-widget-woocommerce-my-account .woocommerce .register p:nth-child(2) {
    margin-top: 10px;
    font-size: 12px; }
  .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-form__input-checkbox {
    vertical-align: middle; }
  .elementor-widget-woocommerce-my-account .woocommerce p:last-of-type {
    margin-bottom: 0; }
  .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-form__label-for-checkbox span {
    color: var(--checkboxes-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce tr,
  .elementor-widget-woocommerce-my-account .woocommerce td,
  .elementor-widget-woocommerce-my-account .woocommerce th {
    border: none; }
  .elementor-widget-woocommerce-my-account .woocommerce h2,
  .elementor-widget-woocommerce-my-account .woocommerce h3 {
    color: var(--typography-section-titles-color, #000000);
    margin-top: 0;
    margin-bottom: var(--section-title-spacing, 45px);
    font-weight: 400; }
  .elementor-widget-woocommerce-my-account .woocommerce strong {
    color: var(--general-text-color, #000000); }
    .elementor-widget-woocommerce-my-account .woocommerce strong.wc-item-meta-label {
      color: var(--variations-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce .wc-item-meta {
    color: var(--variations-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce .product-quantity {
    font-weight: 400;
    color: var(--tables-items-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce .woocommerce-order-downloads {
    margin-bottom: 0; }
  .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation {
    float: left;
    width: 25%;
    /* 25% to match the design */ }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation {
        width: 100%; } }
    .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul {
      -webkit-padding-start: 0;
              padding-inline-start: 0; }
      .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li {
        list-style-type: none;
        margin: calc(var(--tabs-spacing, 2px) / 2) 0 calc(var(--tabs-spacing, 2px) / 2) 0;
        display: inline-block;
        width: 100%;
        /* add a Divider between the tabs that is outside of the margins */ }
        .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li::after {
          content: "";
          display: block;
          width: 100%;
          background-color: var(--tabs-divider-color, #818a91);
          height: var(--tabs-divider-weight, 0px);
          position: relative;
          top: calc(var(--tabs-spacing, 2px) / 2); }
        .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li.is-active a {
          color: var(--tabs-active-color, #5bc0de);
          background: #eceeef;
          border-color: var(--tabs-active-border-color, transparent); }
        .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li a {
          font-style: normal;
          font-weight: bold;
          font-size: 14px;
          color: var(--tabs-normal-color, #818a91);
          display: block;
          padding: var(--tabs-padding, 12px 20px);
          text-align: var(--tabs-alignment, start);
          background: #f7f7f7;
          border-radius: var(--tabs-border-radius, 0px);
          border-style: var(--tabs-border-type, solid);
          border-color: var(--tabs-border-color, transparent);
          border-width: 0px; }
          .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li a:hover {
            color: var(--tabs-hover-color, #5bc0de);
            border-color: var(--tabs-hover-border-color, transparent); }
          @media (max-width: 1024px) {
            .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li a {
              padding: var(--tabs-padding, 10px); } }
        .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--dashboard {
          margin-top: 0; }
        .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--customer-logout {
          margin-bottom: 0; }
          .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-navigation ul li.woocommerce-MyAccount-navigation-link--customer-logout::after {
            display: none; }
  .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content {
    float: right;
    width: 75%;
    /* 75% to match the design */
    padding: 0;
    padding-left: var(--tab-content-spacing, 6%);
    /* 6% to match the design */ }
    @media (max-width: 1024px) {
      .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content {
        width: 100%;
        padding: var(--tab-content-spacing, 6%) 0 0 0; } }
    .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content-wrapper {
      font-size: 14px; }
    .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content p:last-of-type {
      margin-bottom: 0; }
    .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content h2:first-of-type {
      margin-top: 30px; }
    .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content mark {
      background-color: transparent;
      font-weight: bold;
      color: var(--general-text-color, #000000); }
  .elementor-widget-woocommerce-my-account .woocommerce caption + thead tr:first-child td,
  .elementor-widget-woocommerce-my-account .woocommerce caption + thead tr:first-child th,
  .elementor-widget-woocommerce-my-account .woocommerce colgroup + thead tr:first-child td,
  .elementor-widget-woocommerce-my-account .woocommerce colgroup + thead tr:first-child th {
    border-top: 0; }
  .elementor-widget-woocommerce-my-account .woocommerce thead:first-child tr:first-child td,
  .elementor-widget-woocommerce-my-account .woocommerce thead:first-child tr:first-child th {
    border-top: 0;
    padding-left: 0;
    padding-top: 0;
    padding-bottom: var(--tables-titles-spacing, 9px); }
  .elementor-widget-woocommerce-my-account .woocommerce tbody > tr:nth-child(odd) > td,
  .elementor-widget-woocommerce-my-account .woocommerce tbody > tr:nth-child(odd) > th,
  .elementor-widget-woocommerce-my-account .woocommerce tbody > tr:nth-child(even) > td,
  .elementor-widget-woocommerce-my-account .woocommerce tbody > tr:nth-child(even) > th {
    background-color: transparent;
    padding-left: 0;
    padding-top: var(--order-summary-rows-gap-top, 9px);
    padding-bottom: var(--order-summary-rows-gap-bottom, 9px);
    color: var(--tables-items-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce tbody .woocommerce-orders-table__cell.woocommerce-orders-table__cell-order-number > a {
    color: var(--tables-links-normal-color, #5bc0de); }
    .elementor-widget-woocommerce-my-account .woocommerce tbody .woocommerce-orders-table__cell.woocommerce-orders-table__cell-order-number > a:hover {
      color: var(--tables-links-hover-color, #5bc0de); }
  .elementor-widget-woocommerce-my-account .woocommerce .shop_table {
    font-size: 14px; }
    .elementor-widget-woocommerce-my-account .woocommerce .shop_table .button {
      background: transparent;
      border-style: var(--tables-buttons-border-type, solid);
      border-color: var(--tables-buttons-border-color, #5bc0de);
      border-radius: var(--tables-button-border-radius, 3px);
      border-width: 2px;
      vertical-align: middle;
      color: var(--tables-button-normal-text-color, #818a91);
      padding: var(--tables-button-padding, 5px 10px); }
      .elementor-widget-woocommerce-my-account .woocommerce .shop_table .button:hover {
        color: var(--tables-button-hover-text-color, #818a91);
        -webkit-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
             -o-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
                transition-duration: var(--tables-button-hover-transition-duration, 0.3s); }
    .elementor-widget-woocommerce-my-account .woocommerce .shop_table td, .elementor-widget-woocommerce-my-account .woocommerce .shop_table th {
      border-top-style: var(--tables-divider-border-type, solid);
      border-top-width: var(--tables-divider-border-width, 1px);
      border-top-color: var(--tables-divider-border-color, #D4D4D4); }
    .elementor-widget-woocommerce-my-account .woocommerce .shop_table thead tr th {
      color: var(--tables-title-color, #000000); }
      .elementor-widget-woocommerce-my-account .woocommerce .shop_table thead tr th span {
        color: var(--tables-title-color, #000000); }
  .elementor-widget-woocommerce-my-account .woocommerce .order_details tfoot th,
  .elementor-widget-woocommerce-my-account .woocommerce .order_details tfoot td {
    padding-left: 0;
    color: var(--tables-title-color, #000000); }
  .elementor-widget-woocommerce-my-account .woocommerce .order_details .download-product a,
  .elementor-widget-woocommerce-my-account .woocommerce .order_details .product-name a {
    color: var(--tables-links-normal-color, #5bc0de); }
    .elementor-widget-woocommerce-my-account .woocommerce .order_details .download-product a:hover,
    .elementor-widget-woocommerce-my-account .woocommerce .order_details .product-name a:hover {
      color: var(--tables-links-hover-color, #5bc0de); }
  .elementor-widget-woocommerce-my-account .woocommerce .order_details .product-purchase-note td {
    border-top: none;
    padding-top: 0; }
  .elementor-widget-woocommerce-my-account .woocommerce .order-again .button {
    background: transparent;
    border: 2px solid #5bc0de;
    border-style: var(--tables-buttons-border-type, solid);
    border-color: var(--tables-buttons-border-color, #5bc0de);
    border-width: 2px;
    border-radius: var(--tables-button-border-radius, 3px);
    vertical-align: middle;
    color: var(--tables-button-normal-text-color, #818a91);
    margin-top: 0;
    margin-bottom: 0;
    padding: var(--tables-button-padding, 12px 32px); }
    .elementor-widget-woocommerce-my-account .woocommerce .order-again .button:hover {
      color: var(--tables-button-hover-text-color, #818a91);
      -webkit-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
           -o-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
              transition-duration: var(--tables-button-hover-transition-duration, 0.3s); }
  .elementor-widget-woocommerce-my-account .woocommerce-Address .title h3, .elementor-widget-woocommerce-my-account .woocommerce-Addresses .title h3 {
    float: none; }
  .elementor-widget-woocommerce-my-account .woocommerce-Address address, .elementor-widget-woocommerce-my-account .woocommerce-Addresses address {
    padding: var(--sections-padding, 45px 30px 16px 30px); }
  .elementor-widget-woocommerce-my-account .woocommerce-Address .edit, .elementor-widget-woocommerce-my-account .woocommerce-Addresses .edit {
    float: left;
    position: absolute;
    margin-left: var(--edit-link-margin-start, 30px);
    margin-top: var(--edit-link-margin-top, 10px); }
  .elementor-widget-woocommerce-my-account .woocommerce .u-columns {
    margin-top: 20px; }
  .elementor-widget-woocommerce-my-account .woocommerce-EditAccountForm fieldset, .elementor-widget-woocommerce-my-account .woocommerce-address-fields fieldset {
    border: none;
    padding: 0;
    -webkit-margin-start: 0;
            margin-inline-start: 0; }
    .elementor-widget-woocommerce-my-account .woocommerce-EditAccountForm fieldset legend, .elementor-widget-woocommerce-my-account .woocommerce-address-fields fieldset legend {
      font-weight: 700;
      padding: 20px 0;
      color: var(--general-text-color, #000000); }
  .elementor-widget-woocommerce-my-account .woocommerce-EditAccountForm .button, .elementor-widget-woocommerce-my-account .woocommerce-address-fields .button {
    background: #5bc0de;
    border: none;
    color: var(--forms-buttons-normal-text-color, #ffffff);
    border-radius: var(--forms-buttons-border-radius, 3px);
    padding: var(--forms-buttons-padding, 12px 32px);
    margin-top: 20px; }
    .elementor-widget-woocommerce-my-account .woocommerce-EditAccountForm .button:hover, .elementor-widget-woocommerce-my-account .woocommerce-address-fields .button:hover {
      color: var(--forms-buttons-hover-text-color, #ffffff);
      -webkit-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
           -o-transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s);
              transition-duration: var(--forms-buttons-hover-transition-duration, 0.3s); }
  .elementor-widget-woocommerce-my-account .woocommerce-pagination {
    padding: 16px 0; }
    .elementor-widget-woocommerce-my-account .woocommerce-pagination .button {
      background: transparent;
      border-style: var(--tables-buttons-border-type, solid);
      border-color: var(--tables-buttons-border-color, #5bc0de);
      border-radius: var(--tables-button-border-radius, 3px);
      border-width: 2px;
      vertical-align: middle;
      color: var(--tables-button-normal-text-color, #818a91);
      padding: var(--tables-button-padding, 5px 10px); }
      .elementor-widget-woocommerce-my-account .woocommerce-pagination .button:hover {
        color: var(--tables-button-hover-text-color, #818a91);
        -webkit-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
             -o-transition-duration: var(--tables-button-hover-transition-duration, 0.3s);
                transition-duration: var(--tables-button-hover-transition-duration, 0.3s); }
  .elementor-widget-woocommerce-my-account .woocommerce-OrderUpdates {
    color: var(--general-text-color, #818a91); }
  .elementor-widget-woocommerce-my-account .woocommerce-table__line-item.order_item .woocommerce-table__product-name.product-purchase-note-is-below {
    padding-bottom: 0; }
  .elementor-widget-woocommerce-my-account .woocommerce-table__line-item.order_item .woocommerce-table__product-total.product-total.product-purchase-note-is-below {
    padding-bottom: 0; }
  .elementor-widget-woocommerce-my-account .e-my-account-tab__view-order .shop_table td {
    vertical-align: top;
    line-height: unset; }

.e-wc-account-tabs-nav .woocommerce-MyAccount-navigation {
  float: none;
  width: 100%; }
  .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li {
    display: inline-block; }

.e-my-account-tabs-vertical .woocommerce-MyAccount-navigation {
  display: block; }

.e-my-account-tabs-vertical .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation {
  display: none; }

.e-my-account-tabs-horizontal .woocommerce-MyAccount-navigation {
  display: none; }

.e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation {
  display: block; }
  .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul {
    list-style: none;
    padding: 0;
    margin: 0;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-pack: var(--tabs-container-justify-content, space-between);
        -ms-flex-pack: var(--tabs-container-justify-content, space-between);
            justify-content: var(--tabs-container-justify-content, space-between); }
    @media (max-width: 767px) {
      .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul {
        display: block; } }
    .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li {
      display: inline-block;
      width: var(--tab-width, 100%);
      padding: 0 calc(var(--tabs-spacing, 2px) / 2) 0 calc(var(--tabs-spacing, 2px) / 2);
      margin: 0;
      border-right-color: var(--tabs-divider-color, #818a91);
      border-right-width: var(--tabs-divider-weight, 0px);
      border-right-style: solid; }
      .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li::after {
        display: none; }
      .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li:first-of-type {
        padding-left: 0; }
      .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li:last-of-type {
        padding-right: 0;
        border-right-width: 0; }
      @media (max-width: 767px) {
        .e-my-account-tabs-horizontal .e-wc-account-tabs-nav .woocommerce-MyAccount-navigation ul li {
          margin: calc(var(--tabs-spacing, 2px) / 2) 0 calc(var(--tabs-spacing, 2px) / 2) 0;
          display: inline-block;
          width: 100%; } }

.e-my-account-tabs-horizontal .woocommerce-MyAccount-content {
  float: none;
  width: 100%;
  padding: var(--tab-content-spacing, 50px) 0 0 0; }

/**
 * Specific styling in the Editor.
 */
.elementor-editor-active,
.elementor-editor-preview {
  /**
	 * Prep for the js switching of tabs when in the editor.
	 */
  /**
	 * Disable all but the first 'View' order button as
	 * this is the only order loaded for preview purposes.
	 */ }
  .elementor-editor-active .elementor-widget-container,
  .elementor-editor-preview .elementor-widget-container {
    min-height: 1px; }
  .elementor-editor-active tr:not(:first-child) .woocommerce-orders-table__cell-order-number a,
  .elementor-editor-preview tr:not(:first-child) .woocommerce-orders-table__cell-order-number a {
    pointer-events: none; }
  .elementor-editor-active tr:not(:first-child) .woocommerce-orders-table__cell-order-actions .button,
  .elementor-editor-preview tr:not(:first-child) .woocommerce-orders-table__cell-order-actions .button {
    pointer-events: none;
    opacity: .3; }

/**
 * Hide all the other My Account pages' content in the Editor except the first one - dashboard page
 */
.elementor-editor-active .elementor-widget-woocommerce-my-account .woocommerce-MyAccount-content:not(:first-of-type) {
  display: none; }

.product .count {
  background-color: inherit; }

.elementor-widget-woocommerce-product-additional-information:not(.elementor-show-heading-yes) h2 {
  display: none; }

.woocommerce div.product.elementor form.cart div.product-addon {
  -ms-flex-preferred-size: 100%;
      flex-basis: 100%;
  -ms-flex-negative: 0;
      flex-shrink: 0; }

.e-sticky-right-column--active {
  position: -webkit-sticky;
  position: sticky;
  top: 0; }

.elementor-theme-builder-content-area {
  height: 400px; }

.elementor-location-header:before,
.elementor-location-footer:before {
  content: '';
  display: table;
  clear: both; }

.elementor-posts.elementor-posts--skin-archive_full_content article.elementor-post {
  display: block; }

.elementor-post-navigation-borders-yes .elementor-post-navigation.elementor-grid {
  color: #D4D4D4;
  border: none;
  border-top: 1px solid;
  border-bottom: 1px solid;
  padding-top: 10px;
  padding-bottom: 10px; }

.elementor-post-navigation-borders-yes .elementor-post-navigation__separator {
  height: 100%;
  width: 1px;
  margin: 0 auto;
  background-color: #D4D4D4; }

.elementor-post-navigation {
  overflow: hidden;
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex; }
  .elementor-post-navigation .post-navigation__arrow-wrapper {
    color: #D4D4D4; }
    .elementor-post-navigation .post-navigation__arrow-wrapper.post-navigation__arrow-prev {
      font-size: 30px;
      padding-right: 15px; }
    .elementor-post-navigation .post-navigation__arrow-wrapper.post-navigation__arrow-next {
      font-size: 30px;
      padding-left: 15px; }
    .elementor-post-navigation .post-navigation__arrow-wrapper i {
      -webkit-transform: translateY(-5%);
          -ms-transform: translateY(-5%);
              transform: translateY(-5%); }
  .elementor-post-navigation .elementor-post-navigation__link__prev, .elementor-post-navigation .elementor-post-navigation__link__next {
    overflow: hidden; }
  .elementor-post-navigation .elementor-post-navigation__link a {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    max-width: 100%; }
  .elementor-post-navigation .post-navigation__prev--label, .elementor-post-navigation .post-navigation__next--label {
    text-transform: uppercase;
    font-size: 0.8em; }
  .elementor-post-navigation .post-navigation__prev--title, .elementor-post-navigation .post-navigation__next--title {
    font-size: 0.7em; }
  .elementor-post-navigation .post-navigation__prev--label, .elementor-post-navigation .post-navigation__prev--title, .elementor-post-navigation .post-navigation__next--label, .elementor-post-navigation .post-navigation__next--title {
    overflow: hidden;
    -o-text-overflow: ellipsis;
       text-overflow: ellipsis; }
  .elementor-post-navigation span.elementor-post-navigation__link__next {
    text-align: right; }
  .elementor-post-navigation span.elementor-post-navigation__link__next, .elementor-post-navigation span.elementor-post-navigation__link__prev {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-orient: vertical;
    -webkit-box-direction: normal;
        -ms-flex-direction: column;
            flex-direction: column; }

.elementor-post-navigation .elementor-grid {
  -webkit-box-pack: justify;
      -ms-flex-pack: justify;
          justify-content: space-between; }

.elementor-post-navigation .elementor-post-navigation__link {
  width: calc( 50% - ( 1px / 2 ));
  white-space: nowrap;
  overflow: hidden;
  -o-text-overflow: ellipsis;
     text-overflow: ellipsis; }

.elementor-post-navigation .elementor-post-navigation__separator-wrapper {
  text-align: center; }

.elementor-post-navigation .elementor-post-navigation__next {
  text-align: right; }
  .elementor-post-navigation .elementor-post-navigation__next a {
    float: right; }

.elementor-search-form {
  display: block;
  -webkit-transition: 0.2s;
  -o-transition: 0.2s;
  transition: 0.2s;
  /*------ Reset ------*/ }
  .elementor-search-form .e-font-icon-svg-container {
    width: 100%;
    height: 100%;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: center;
        -ms-flex-pack: center;
            justify-content: center; }
  .elementor-search-form input[type="search"], .elementor-search-form button {
    margin: 0;
    border: 0;
    padding: 0;
    display: inline-block;
    vertical-align: middle;
    white-space: normal;
    background: none;
    line-height: 1;
    min-width: 0;
    font-size: 15px;
    -webkit-appearance: none;
    -moz-appearance: none; }
    .elementor-search-form input[type="search"]:focus, .elementor-search-form button:focus {
      outline: 0;
      color: inherit; }
  .elementor-search-form button {
    background-color: #818a91;
    font-size: var(--e-search-form-submit-icon-size, 16px);
    color: #fff;
    border-radius: 0; }
  .elementor-search-form__container {
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-transition: 0.2s;
    -o-transition: 0.2s;
    transition: 0.2s;
    overflow: hidden;
    border: 0 solid transparent;
    min-height: 50px; }
    .elementor-search-form__container:not(.elementor-search-form--full-screen) {
      background: #eceeef; }
  .elementor-search-form__input {
    -ms-flex-preferred-size: 100%;
        flex-basis: 100%;
    color: #55595c;
    -webkit-transition: color 0.2s;
    -o-transition: color 0.2s;
    transition: color 0.2s; }
    .elementor-search-form__input::-webkit-input-placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
    .elementor-search-form__input:-ms-input-placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
    .elementor-search-form__input::-moz-placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
    .elementor-search-form__input:-moz-placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
    .elementor-search-form__input::-ms-input-placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
    .elementor-search-form__input::placeholder {
      color: inherit;
      font-family: inherit;
      opacity: 0.6; }
  .elementor-search-form__submit {
    -webkit-transition: color 0.2s, background 0.2s;
    -o-transition: color 0.2s, background 0.2s;
    transition: color 0.2s, background 0.2s;
    font-size: var(--e-search-form-submit-icon-size, 16px); }
    .elementor-search-form__submit svg {
      fill: var(--e-search-form-submit-text-color, #fff);
      width: var(--e-search-form-submit-icon-size, 16px);
      height: var(--e-search-form-submit-icon-size, 16px); }
  .elementor-search-form .elementor-search-form__submit, .elementor-search-form .elementor-search-form__submit:hover {
    color: var(--e-search-form-submit-text-color, #fff);
    border: none;
    border-radius: 0; }
  .elementor-search-form--button-type-text .elementor-search-form__submit {
    -ms-flex-negative: 0;
        flex-shrink: 0; }
  .elementor-search-form--skin-minimal .elementor-search-form__icon {
    opacity: 0.6;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    -webkit-box-pack: end;
        -ms-flex-pack: end;
            justify-content: flex-end;
    color: #55595c;
    fill: #55595c;
    font-size: var(--e-search-form-icon-size-minimal, 15px); }
    .elementor-search-form--skin-minimal .elementor-search-form__icon svg {
      width: var(--e-search-form-icon-size-minimal, 15px);
      height: var(--e-search-form-icon-size-minimal, 15px); }
  .elementor-search-form--skin-full_screen .elementor-search-form input[type="search"].elementor-search-form__input {
    font-size: 50px;
    text-align: center;
    border-style: solid;
    border-width: 0 0 1px 0;
    border-color: #fff;
    line-height: 1.5;
    color: #fff; }
  .elementor-search-form--skin-full_screen .elementor-search-form__toggle {
    display: inline-block;
    cursor: pointer;
    vertical-align: middle;
    color: var(--e-search-form-toggle-color, #494c4f);
    font-size: var(--e-search-form-toggle-size, 33px); }
    .elementor-search-form--skin-full_screen .elementor-search-form__toggle i,
    .elementor-search-form--skin-full_screen .elementor-search-form__toggle .e-font-icon-svg-container {
      position: relative;
      display: block;
      -webkit-transition: 0.2s;
      -o-transition: 0.2s;
      transition: 0.2s;
      width: var(--e-search-form-toggle-size, 33px);
      height: var(--e-search-form-toggle-size, 33px);
      background-color: var(--e-search-form-toggle-background-color, rgba(0, 0, 0, 0.05));
      border-style: solid;
      border-color: var(--e-search-form-toggle-color, #494c4f);
      border-width: var(--e-search-form-toggle-border-width, 0);
      border-radius: var(--e-search-form-toggle-border-radius, 3px); }
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle i:before,
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle i svg,
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle .e-font-icon-svg-container:before,
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle .e-font-icon-svg-container svg {
        position: absolute;
        left: 50%;
        top: 50%;
        -webkit-transform: translate(-50%, -50%);
            -ms-transform: translate(-50%, -50%);
                transform: translate(-50%, -50%); }
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle i:before,
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle .e-font-icon-svg-container:before {
        font-size: var(--e-search-form-toggle-icon-size, 0.55em); }
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle i svg,
      .elementor-search-form--skin-full_screen .elementor-search-form__toggle .e-font-icon-svg-container svg {
        fill: var(--e-search-form-toggle-color, #494c4f);
        width: var(--e-search-form-toggle-icon-size, 0.55em);
        height: var(--e-search-form-toggle-icon-size, 0.55em); }
  .elementor-search-form--skin-full_screen .elementor-search-form__container {
    -webkit-transition: 0.3s;
    -o-transition: 0.3s;
    transition: 0.3s;
    -webkit-box-align: center;
        -ms-flex-align: center;
            align-items: center;
    position: fixed;
    z-index: 9998;
    top: 0;
    left: 0;
    right: 0;
    bottom: 0;
    height: 100vh;
    padding: 0 15%;
    background-color: rgba(0, 0, 0, 0.8); }
    .elementor-search-form--skin-full_screen .elementor-search-form__container:not(.elementor-search-form--full-screen) {
      overflow: hidden;
      opacity: 0;
      -webkit-transform: scale(0);
          -ms-transform: scale(0);
              transform: scale(0); }
      .elementor-search-form--skin-full_screen .elementor-search-form__container:not(.elementor-search-form--full-screen) .dialog-lightbox-close-button {
        display: none; }

.elementor-author-box {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-align: center;
      -ms-flex-align: center;
          align-items: center; }
  .elementor-author-box__avatar {
    -ms-flex-negative: 0;
        flex-shrink: 0;
    margin-right: 25px; }
    .elementor-author-box__avatar img {
      width: 100px;
      border-radius: 500px;
      -o-object-fit: cover;
         object-fit: cover; }
  .elementor-author-box__text {
    -webkit-box-flex: 1;
        -ms-flex-positive: 1;
            flex-grow: 1;
    font-size: 17px; }
  .elementor-author-box__name {
    font-size: 24px;
    margin-bottom: 5px; }
  .elementor-author-box__bio {
    margin-bottom: 0.8em; }
    .elementor-author-box__bio p {
      margin-bottom: 0.8em; }
      .elementor-author-box__bio p:last-of-type {
        margin-bottom: 0; }
  .elementor-author-box--layout-image-left .elementor-author-box {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: normal;
        -ms-flex-direction: row;
            flex-direction: row; }
    .elementor-author-box--layout-image-left .elementor-author-box__avatar {
      margin-left: 0;
      margin-right: 25px; }
  .elementor-author-box--layout-image-right .elementor-author-box {
    -webkit-box-orient: horizontal;
    -webkit-box-direction: reverse;
        -ms-flex-direction: row-reverse;
            flex-direction: row-reverse; }
    .elementor-author-box--layout-image-right .elementor-author-box__avatar {
      margin-right: 0;
      margin-left: 25px; }
  .elementor-author-box--layout-image-above .elementor-author-box {
    display: block; }
    .elementor-author-box--layout-image-above .elementor-author-box__avatar {
      margin: 0 auto 15px;
      display: inline-block; }
  .elementor-author-box--layout-image-above.elementor-author-box--align-left .elementor-author-box__avatar {
    margin-left: 0; }
  .elementor-author-box--layout-image-above.elementor-author-box--align-right .elementor-author-box__avatar {
    margin-right: 0; }
  .elementor-author-box--align-left .elementor-author-box {
    text-align: left; }
  .elementor-author-box--align-right .elementor-author-box {
    text-align: right; }
  .elementor-author-box--align-center .elementor-author-box {
    text-align: center; }

.elementor-button.elementor-author-box__button {
  border: solid 2px #55595c;
  font-size: 15px;
  font-weight: 100;
  padding: 10px 18px; }
  .elementor-button.elementor-author-box__button, .elementor-button.elementor-author-box__button:hover {
    background: transparent;
    color: #55595c; }

.elementor-widget-author-box:not(.elementor-author-box--layout-image-above) .elementor-author-box__avatar {
  -ms-flex-item-align: start;
      align-self: flex-start; }

.elementor-widget-author-box:not(.elementor-author-box--layout-image-above).elementor-author-box--image-valign-top .elementor-author-box__avatar {
  -ms-flex-item-align: start;
      align-self: flex-start; }

.elementor-widget-author-box:not(.elementor-author-box--layout-image-above).elementor-author-box--image-valign-middle .elementor-author-box__avatar {
  -ms-flex-item-align: center;
      align-self: center; }

.elementor-post-info__terms-list {
  display: inline-block; }

.elementor-post-info .elementor-icon-list-icon .elementor-avatar {
  border-radius: 100%; }

.elementor-widget-post-info.elementor-align-center .elementor-icon-list-item:after {
  margin: initial; }

.elementor-icon-list-items .elementor-icon-list-item .elementor-icon-list-text {
  display: inline-block; }
  .elementor-icon-list-items .elementor-icon-list-item .elementor-icon-list-text a, .elementor-icon-list-items .elementor-icon-list-item .elementor-icon-list-text span {
    display: inline; }

.elementor-widget-breadcrumbs {
  font-size: 0.85em; }
  .elementor-widget-breadcrumbs p {
    margin-bottom: 0; }

.elementor-sitemap-wrap {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  -webkit-box-orient: horizontal;
  -webkit-box-direction: normal;
      -ms-flex-flow: row wrap;
          flex-flow: row wrap; }

.elementor-sticky--active {
  z-index: 99; }

[data-elementor-type="popup"]:not(.elementor-edit-area) {
  display: none; }

[data-elementor-type="popup"] .elementor-section-wrap:not(:empty) + #elementor-add-new-section {
  display: none; }

.elementor-popup-modal {
  display: -webkit-box;
  display: -ms-flexbox;
  display: flex;
  pointer-events: none;
  background-color: transparent;
  -webkit-user-select: auto;
     -moz-user-select: auto;
      -ms-user-select: auto;
          user-select: auto; }
  .elementor-popup-modal .dialog-header, .elementor-popup-modal .dialog-buttons-wrapper {
    display: none; }
  .elementor-popup-modal .dialog-close-button {
    display: none;
    top: 20px;
    margin-top: 0;
    right: 20px;
    opacity: 1;
    z-index: 9999;
    pointer-events: all; }
    .elementor-popup-modal .dialog-close-button svg {
      fill: #373a3c;
      height: 1em;
      width: 1em; }
  .elementor-popup-modal .dialog-widget-content {
    width: initial;
    overflow: visible;
    max-width: 100%;
    max-height: 100%;
    border-radius: 0;
    -webkit-box-shadow: none;
            box-shadow: none;
    pointer-events: all; }
  .elementor-popup-modal .dialog-message {
    width: 640px;
    max-width: 100vw;
    max-height: 100vh;
    padding: 0;
    overflow: auto;
    display: -webkit-box;
    display: -ms-flexbox;
    display: flex; }
  .elementor-popup-modal .elementor {
    width: 100%; }

.elementor-motion-effects-element, .elementor-motion-effects-layer {
  -webkit-transition-property: opacity, -webkit-transform;
  transition-property: opacity, -webkit-transform;
  -o-transition-property: transform, opacity;
  transition-property: transform, opacity;
  transition-property: transform, opacity, -webkit-transform;
  -webkit-transition-timing-function: cubic-bezier(0, 0.33, 0.07, 1.03);
       -o-transition-timing-function: cubic-bezier(0, 0.33, 0.07, 1.03);
          transition-timing-function: cubic-bezier(0, 0.33, 0.07, 1.03);
  -webkit-transition-duration: 1s;
       -o-transition-duration: 1s;
          transition-duration: 1s; }

.elementor-motion-effects-container {
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  overflow: hidden;
  -webkit-transform-origin: var(--e-transform-origin-y) var(--e-transform-origin-x);
      -ms-transform-origin: var(--e-transform-origin-y) var(--e-transform-origin-x);
          transform-origin: var(--e-transform-origin-y) var(--e-transform-origin-x); }

.elementor-motion-effects-layer {
  position: absolute;
  top: 0;
  left: 0;
  background-repeat: no-repeat;
  -webkit-background-size: cover;
          background-size: cover; }

.elementor-motion-effects-perspective {
  -webkit-perspective: 1200px;
          perspective: 1200px; }
/*# sourceMappingURL=frontend-lite.css.map */